Class: Google::Apis::DataformV1::ActionLoadConfig
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1::ActionLoadConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb
Overview
Simplified load configuration for actions
Instance Attribute Summary collapse
-
#append ⇒ Google::Apis::DataformV1::ActionSimpleLoadMode
Simple load definition Corresponds to the JSON property
append. -
#maximum ⇒ Google::Apis::DataformV1::ActionIncrementalLoadMode
Load definition for incremental load modes Corresponds to the JSON property
maximum. -
#replace ⇒ Google::Apis::DataformV1::ActionSimpleLoadMode
Simple load definition Corresponds to the JSON property
replace. -
#unique ⇒ Google::Apis::DataformV1::ActionIncrementalLoadMode
Load definition for incremental load modes Corresponds to the JSON property
unique.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ActionLoadConfig
constructor
A new instance of ActionLoadConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ActionLoadConfig
Returns a new instance of ActionLoadConfig.
94 95 96 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 94 def initialize(**args) update!(**args) end |
Instance Attribute Details
#append ⇒ Google::Apis::DataformV1::ActionSimpleLoadMode
Simple load definition
Corresponds to the JSON property append
77 78 79 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 77 def append @append end |
#maximum ⇒ Google::Apis::DataformV1::ActionIncrementalLoadMode
Load definition for incremental load modes
Corresponds to the JSON property maximum
82 83 84 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 82 def maximum @maximum end |
#replace ⇒ Google::Apis::DataformV1::ActionSimpleLoadMode
Simple load definition
Corresponds to the JSON property replace
87 88 89 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 87 def replace @replace end |
#unique ⇒ Google::Apis::DataformV1::ActionIncrementalLoadMode
Load definition for incremental load modes
Corresponds to the JSON property unique
92 93 94 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 92 def unique @unique end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
99 100 101 102 103 104 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 99 def update!(**args) @append = args[:append] if args.key?(:append) @maximum = args[:maximum] if args.key?(:maximum) @replace = args[:replace] if args.key?(:replace) @unique = args[:unique] if args.key?(:unique) end |