Class: Google::Apis::DataformV1::ActionSqlDefinition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb

Overview

Definition of a SQL Data Preparation

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ActionSqlDefinition

Returns a new instance of ActionSqlDefinition.



140
141
142
# File 'lib/google/apis/dataform_v1/classes.rb', line 140

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_tableGoogle::Apis::DataformV1::ActionErrorTable

Error table information, used to write error data into a BigQuery table. Corresponds to the JSON property errorTable



127
128
129
# File 'lib/google/apis/dataform_v1/classes.rb', line 127

def error_table
  @error_table
end

#load_configGoogle::Apis::DataformV1::ActionLoadConfig

Simplified load configuration for actions Corresponds to the JSON property loadConfig



132
133
134
# File 'lib/google/apis/dataform_v1/classes.rb', line 132

def load_config
  @load_config
end

#queryString

The SQL query representing the data preparation steps. Formatted as a Pipe SQL query statement. Corresponds to the JSON property query

Returns:

  • (String)


138
139
140
# File 'lib/google/apis/dataform_v1/classes.rb', line 138

def query
  @query
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



145
146
147
148
149
# File 'lib/google/apis/dataform_v1/classes.rb', line 145

def update!(**args)
  @error_table = args[:error_table] if args.key?(:error_table)
  @load_config = args[:load_config] if args.key?(:load_config)
  @query = args[:query] if args.key?(:query)
end