Class: Google::Apis::DataformV1::BigQueryAction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb

Overview

Represents a workflow action that will run against BigQuery.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BigQueryAction

Returns a new instance of BigQueryAction.



219
220
221
# File 'lib/google/apis/dataform_v1/classes.rb', line 219

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#job_idString

Output only. The ID of the BigQuery job that executed the SQL in sql_script. Only set once the job has started to run. Corresponds to the JSON property jobId

Returns:

  • (String)


212
213
214
# File 'lib/google/apis/dataform_v1/classes.rb', line 212

def job_id
  @job_id
end

#sql_scriptString

Output only. The generated BigQuery SQL script that will be executed. Corresponds to the JSON property sqlScript

Returns:

  • (String)


217
218
219
# File 'lib/google/apis/dataform_v1/classes.rb', line 217

def sql_script
  @sql_script
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



224
225
226
227
# File 'lib/google/apis/dataform_v1/classes.rb', line 224

def update!(**args)
  @job_id = args[:job_id] if args.key?(:job_id)
  @sql_script = args[:sql_script] if args.key?(:sql_script)
end