Class: Google::Apis::DataformV1::CodeCompilationConfig
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1::CodeCompilationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb
Overview
Configures various aspects of Dataform code compilation.
Instance Attribute Summary collapse
-
#assertion_schema ⇒ String
Optional.
-
#builtin_assertion_name_prefix ⇒ String
Optional.
-
#database_suffix ⇒ String
Optional.
-
#default_database ⇒ String
Optional.
-
#default_location ⇒ String
Optional.
-
#default_notebook_runtime_options ⇒ Google::Apis::DataformV1::NotebookRuntimeOptions
Configures various aspects of Dataform notebook runtime.
-
#default_schema ⇒ String
Optional.
-
#schema_suffix ⇒ String
Optional.
-
#table_prefix ⇒ String
Optional.
-
#vars ⇒ Hash<String,String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CodeCompilationConfig
constructor
A new instance of CodeCompilationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CodeCompilationConfig
Returns a new instance of CodeCompilationConfig.
429 430 431 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 429 def initialize(**args) update!(**args) end |
Instance Attribute Details
#assertion_schema ⇒ String
Optional. The default schema (BigQuery dataset ID) for assertions.
Corresponds to the JSON property assertionSchema
377 378 379 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 377 def assertion_schema @assertion_schema end |
#builtin_assertion_name_prefix ⇒ String
Optional. The prefix to prepend to built-in assertion names.
Corresponds to the JSON property builtinAssertionNamePrefix
382 383 384 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 382 def builtin_assertion_name_prefix @builtin_assertion_name_prefix end |
#database_suffix ⇒ String
Optional. The suffix that should be appended to all database (Google Cloud
project ID) names.
Corresponds to the JSON property databaseSuffix
388 389 390 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 388 def database_suffix @database_suffix end |
#default_database ⇒ String
Optional. The default database (Google Cloud project ID).
Corresponds to the JSON property defaultDatabase
393 394 395 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 393 def default_database @default_database end |
#default_location ⇒ String
Optional. The default BigQuery location to use. Defaults to "US". See the
BigQuery docs for a full list of locations: https://cloud.google.com/bigquery/
docs/locations.
Corresponds to the JSON property defaultLocation
400 401 402 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 400 def default_location @default_location end |
#default_notebook_runtime_options ⇒ Google::Apis::DataformV1::NotebookRuntimeOptions
Configures various aspects of Dataform notebook runtime.
Corresponds to the JSON property defaultNotebookRuntimeOptions
405 406 407 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 405 def @default_notebook_runtime_options end |
#default_schema ⇒ String
Optional. The default schema (BigQuery dataset ID).
Corresponds to the JSON property defaultSchema
410 411 412 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 410 def default_schema @default_schema end |
#schema_suffix ⇒ String
Optional. The suffix that should be appended to all schema (BigQuery dataset
ID) names.
Corresponds to the JSON property schemaSuffix
416 417 418 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 416 def schema_suffix @schema_suffix end |
#table_prefix ⇒ String
Optional. The prefix that should be prepended to all table names.
Corresponds to the JSON property tablePrefix
421 422 423 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 421 def table_prefix @table_prefix end |
#vars ⇒ Hash<String,String>
Optional. User-defined variables that are made available to project code
during compilation.
Corresponds to the JSON property vars
427 428 429 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 427 def vars @vars end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
434 435 436 437 438 439 440 441 442 443 444 445 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 434 def update!(**args) @assertion_schema = args[:assertion_schema] if args.key?(:assertion_schema) @builtin_assertion_name_prefix = args[:builtin_assertion_name_prefix] if args.key?(:builtin_assertion_name_prefix) @database_suffix = args[:database_suffix] if args.key?(:database_suffix) @default_database = args[:default_database] if args.key?(:default_database) @default_location = args[:default_location] if args.key?(:default_location) @default_notebook_runtime_options = args[:default_notebook_runtime_options] if args.key?(:default_notebook_runtime_options) @default_schema = args[:default_schema] if args.key?(:default_schema) @schema_suffix = args[:schema_suffix] if args.key?(:schema_suffix) @table_prefix = args[:table_prefix] if args.key?(:table_prefix) @vars = args[:vars] if args.key?(:vars) end |