Class: Google::Apis::DataformV1::CommitRepositoryChangesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb

Overview

CommitRepositoryChanges request message.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CommitRepositoryChangesRequest

Returns a new instance of CommitRepositoryChangesRequest.



589
590
591
# File 'lib/google/apis/dataform_v1/classes.rb', line 589

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commit_metadataGoogle::Apis::DataformV1::CommitMetadata

Represents a Dataform Git commit. Corresponds to the JSON property commitMetadata



574
575
576
# File 'lib/google/apis/dataform_v1/classes.rb', line 574

def 
  @commit_metadata
end

#file_operationsHash<String,Google::Apis::DataformV1::FileOperation>

Optional. A map to the path of the file to the operation. The path is the full file path including filename, from repository root. Corresponds to the JSON property fileOperations

Returns:



580
581
582
# File 'lib/google/apis/dataform_v1/classes.rb', line 580

def file_operations
  @file_operations
end

#required_head_commit_shaString

Optional. The commit SHA which must be the repository's current HEAD before applying this commit; otherwise this request will fail. If unset, no validation on the current HEAD commit SHA is performed. Corresponds to the JSON property requiredHeadCommitSha

Returns:

  • (String)


587
588
589
# File 'lib/google/apis/dataform_v1/classes.rb', line 587

def required_head_commit_sha
  @required_head_commit_sha
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



594
595
596
597
598
# File 'lib/google/apis/dataform_v1/classes.rb', line 594

def update!(**args)
  @commit_metadata = args[:commit_metadata] if args.key?(:commit_metadata)
  @file_operations = args[:file_operations] if args.key?(:file_operations)
  @required_head_commit_sha = args[:required_head_commit_sha] if args.key?(:required_head_commit_sha)
end