Class: Google::Apis::DataformV1::DataPreparation
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1::DataPreparation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb
Overview
Defines a compiled Data Preparation entity
Instance Attribute Summary collapse
-
#contents_sql ⇒ Google::Apis::DataformV1::SqlDefinition
Definition of a SQL Data Preparation Corresponds to the JSON property
contentsSql. -
#contents_yaml ⇒ String
The data preparation definition, stored as a YAML string.
-
#dependency_targets ⇒ Array<Google::Apis::DataformV1::Target>
A list of actions that this action depends on.
-
#disabled ⇒ Boolean
(also: #disabled?)
Whether this action is disabled (i.e. should not be run).
-
#tags ⇒ Array<String>
Arbitrary, user-defined tags on this action.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DataPreparation
constructor
A new instance of DataPreparation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DataPreparation
Returns a new instance of DataPreparation.
977 978 979 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 977 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contents_sql ⇒ Google::Apis::DataformV1::SqlDefinition
Definition of a SQL Data Preparation
Corresponds to the JSON property contentsSql
954 955 956 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 954 def contents_sql @contents_sql end |
#contents_yaml ⇒ String
The data preparation definition, stored as a YAML string.
Corresponds to the JSON property contentsYaml
959 960 961 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 959 def contents_yaml @contents_yaml end |
#dependency_targets ⇒ Array<Google::Apis::DataformV1::Target>
A list of actions that this action depends on.
Corresponds to the JSON property dependencyTargets
964 965 966 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 964 def dependency_targets @dependency_targets end |
#disabled ⇒ Boolean Also known as: disabled?
Whether this action is disabled (i.e. should not be run).
Corresponds to the JSON property disabled
969 970 971 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 969 def disabled @disabled end |
#tags ⇒ Array<String>
Arbitrary, user-defined tags on this action.
Corresponds to the JSON property tags
975 976 977 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 975 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
982 983 984 985 986 987 988 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 982 def update!(**args) @contents_sql = args[:contents_sql] if args.key?(:contents_sql) @contents_yaml = args[:contents_yaml] if args.key?(:contents_yaml) @dependency_targets = args[:dependency_targets] if args.key?(:dependency_targets) @disabled = args[:disabled] if args.key?(:disabled) @tags = args[:tags] if args.key?(:tags) end |