Class: Google::Apis::DataformV1::DeleteTeamFolderTreeRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb

Overview

DeleteTeamFolderTree request message.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeleteTeamFolderTreeRequest

Returns a new instance of DeleteTeamFolderTreeRequest.



1114
1115
1116
# File 'lib/google/apis/dataform_v1/classes.rb', line 1114

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#forceBoolean Also known as: force?

Optional. If false (default): The operation will fail if any Repository within the folder hierarchy has associated Release Configs or Workflow Configs. If true: The operation will attempt to delete everything, including any Release Configs and Workflow Configs linked to Repositories within the folder hierarchy. This permanently removes schedules and resources. Corresponds to the JSON property force

Returns:

  • (Boolean)


1111
1112
1113
# File 'lib/google/apis/dataform_v1/classes.rb', line 1111

def force
  @force
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1119
1120
1121
# File 'lib/google/apis/dataform_v1/classes.rb', line 1119

def update!(**args)
  @force = args[:force] if args.key?(:force)
end