Class: Google::Apis::DataformV1::DirectoryEntry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb

Overview

Represents a single entry in a directory.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DirectoryEntry

Returns a new instance of DirectoryEntry.



1133
1134
1135
# File 'lib/google/apis/dataform_v1/classes.rb', line 1133

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#directoryString

A child directory in the directory. The path is returned including the full folder structure from the root. Corresponds to the JSON property directory

Returns:

  • (String)


1120
1121
1122
# File 'lib/google/apis/dataform_v1/classes.rb', line 1120

def directory
  @directory
end

#fileString

A file in the directory. The path is returned including the full folder structure from the root. Corresponds to the JSON property file

Returns:

  • (String)


1126
1127
1128
# File 'lib/google/apis/dataform_v1/classes.rb', line 1126

def file
  @file
end

#metadataGoogle::Apis::DataformV1::FilesystemEntryMetadata

Represents metadata for a single entry in a filesystem. Corresponds to the JSON property metadata



1131
1132
1133
# File 'lib/google/apis/dataform_v1/classes.rb', line 1131

def 
  @metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1138
1139
1140
1141
1142
# File 'lib/google/apis/dataform_v1/classes.rb', line 1138

def update!(**args)
  @directory = args[:directory] if args.key?(:directory)
  @file = args[:file] if args.key?(:file)
  @metadata = args[:metadata] if args.key?(:metadata)
end