Class: Google::Apis::DataformV1::FetchFileGitStatusesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb

Overview

FetchFileGitStatuses response message.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FetchFileGitStatusesResponse

Returns a new instance of FetchFileGitStatusesResponse.



1301
1302
1303
# File 'lib/google/apis/dataform_v1/classes.rb', line 1301

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#uncommitted_file_changesArray<Google::Apis::DataformV1::UncommittedFileChange>

A list of all files which have uncommitted Git changes. There will only be a single entry for any given file. Corresponds to the JSON property uncommittedFileChanges



1299
1300
1301
# File 'lib/google/apis/dataform_v1/classes.rb', line 1299

def uncommitted_file_changes
  @uncommitted_file_changes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1306
1307
1308
# File 'lib/google/apis/dataform_v1/classes.rb', line 1306

def update!(**args)
  @uncommitted_file_changes = args[:uncommitted_file_changes] if args.key?(:uncommitted_file_changes)
end