Class: Google::Apis::DataformV1::Folder
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1::Folder
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb
Overview
Represents a Dataform Folder. This is a resource that is used to organize Files and other Folders and provide hierarchical access controls.
Instance Attribute Summary collapse
-
#containing_folder ⇒ String
Optional.
-
#create_time ⇒ String
Output only.
-
#creator_iam_principal ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#internal_metadata ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#team_folder_name ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Folder
constructor
A new instance of Folder.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Folder
Returns a new instance of Folder.
1492 1493 1494 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1492 def initialize(**args) update!(**args) end |
Instance Attribute Details
#containing_folder ⇒ String
Optional. The containing Folder resource name. This should take the format:
projects/project/locations/location/folders/folder, projects/project/
locations/location/teamFolders/teamFolder, or just "" if this is a root
Folder. This field can only be updated through MoveFolder.
Corresponds to the JSON property containingFolder
1450 1451 1452 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1450 def containing_folder @containing_folder end |
#create_time ⇒ String
Output only. The timestamp of when the Folder was created.
Corresponds to the JSON property createTime
1455 1456 1457 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1455 def create_time @create_time end |
#creator_iam_principal ⇒ String
Output only. The IAM principal identifier of the creator of the Folder.
Corresponds to the JSON property creatorIamPrincipal
1460 1461 1462 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1460 def creator_iam_principal @creator_iam_principal end |
#display_name ⇒ String
Required. The Folder's user-friendly name.
Corresponds to the JSON property displayName
1465 1466 1467 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1465 def display_name @display_name end |
#internal_metadata ⇒ String
Output only. All the metadata information that is used internally to serve the
resource. For example: timestamps, flags, status fields, etc. The format of
this field is a JSON string.
Corresponds to the JSON property internalMetadata
1472 1473 1474 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1472 def @internal_metadata end |
#name ⇒ String
Identifier. The Folder's name.
Corresponds to the JSON property name
1477 1478 1479 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1477 def name @name end |
#team_folder_name ⇒ String
Output only. The resource name of the TeamFolder that this Folder is
associated with. This should take the format: projects/project/locations/
location/teamFolders/teamFolder. If this is not set, the Folder is not
associated with a TeamFolder and is a UserFolder.
Corresponds to the JSON property teamFolderName
1485 1486 1487 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1485 def team_folder_name @team_folder_name end |
#update_time ⇒ String
Output only. The timestamp of when the Folder was last updated.
Corresponds to the JSON property updateTime
1490 1491 1492 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1490 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1497 def update!(**args) @containing_folder = args[:containing_folder] if args.key?(:containing_folder) @create_time = args[:create_time] if args.key?(:create_time) @creator_iam_principal = args[:creator_iam_principal] if args.key?(:creator_iam_principal) @display_name = args[:display_name] if args.key?(:display_name) @internal_metadata = args[:internal_metadata] if args.key?(:internal_metadata) @name = args[:name] if args.key?(:name) @team_folder_name = args[:team_folder_name] if args.key?(:team_folder_name) @update_time = args[:update_time] if args.key?(:update_time) end |