Class: Google::Apis::DataformV1::IamPolicyOverrideView
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1::IamPolicyOverrideView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb
Overview
Contains metadata about the IAM policy override for a given Dataform resource. If is_active is true, this the policy encoded in iam_policy_name is the source of truth for this resource. Will be provided in internal ESV2 views for: Workspaces, Repositories, Folders, TeamFolders.
Instance Attribute Summary collapse
-
#iam_policy_name ⇒ Google::Apis::DataformV1::PolicyName
An internal name for an IAM policy, based on the resource to which the policy applies.
-
#is_active ⇒ Boolean
(also: #is_active?)
Whether the IAM policy encoded in this view is active.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IamPolicyOverrideView
constructor
A new instance of IamPolicyOverrideView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IamPolicyOverrideView
Returns a new instance of IamPolicyOverrideView.
1600 1601 1602 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1600 def initialize(**args) update!(**args) end |
Instance Attribute Details
#iam_policy_name ⇒ Google::Apis::DataformV1::PolicyName
An internal name for an IAM policy, based on the resource to which the policy
applies. Not to be confused with a resource's external full resource name. For
more information on this distinction, see go/iam-full-resource-names.
Corresponds to the JSON property iamPolicyName
1592 1593 1594 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1592 def iam_policy_name @iam_policy_name end |
#is_active ⇒ Boolean Also known as: is_active?
Whether the IAM policy encoded in this view is active.
Corresponds to the JSON property isActive
1597 1598 1599 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1597 def is_active @is_active end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1605 1606 1607 1608 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1605 def update!(**args) @iam_policy_name = args[:iam_policy_name] if args.key?(:iam_policy_name) @is_active = args[:is_active] if args.key?(:is_active) end |