Class: Google::Apis::DataformV1::InstallNpmPackagesRequest
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1::InstallNpmPackagesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb
Overview
InstallNpmPackages request message.
Instance Attribute Summary collapse
-
#pipeline_config ⇒ Google::Apis::DataformV1::PipelineConfig
Defines the pipeline type and path within the Git repository.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstallNpmPackagesRequest
constructor
A new instance of InstallNpmPackagesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstallNpmPackagesRequest
Returns a new instance of InstallNpmPackagesRequest.
1776 1777 1778 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1776 def initialize(**args) update!(**args) end |
Instance Attribute Details
#pipeline_config ⇒ Google::Apis::DataformV1::PipelineConfig
Defines the pipeline type and path within the Git repository.
Corresponds to the JSON property pipelineConfig
1774 1775 1776 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1774 def pipeline_config @pipeline_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1781 1782 1783 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1781 def update!(**args) @pipeline_config = args[:pipeline_config] if args.key?(:pipeline_config) end |