Class: Google::Apis::DataformV1::InvocationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb

Overview

Includes various configuration options for a workflow invocation. If both included_targets and included_tags are unset, all actions will be included.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InvocationConfig

Returns a new instance of InvocationConfig.



1804
1805
1806
# File 'lib/google/apis/dataform_v1/classes.rb', line 1804

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fully_refresh_incremental_tables_enabledBoolean Also known as: fully_refresh_incremental_tables_enabled?

Optional. When set to true, any incremental tables will be fully refreshed. Corresponds to the JSON property fullyRefreshIncrementalTablesEnabled

Returns:

  • (Boolean)


1765
1766
1767
# File 'lib/google/apis/dataform_v1/classes.rb', line 1765

def fully_refresh_incremental_tables_enabled
  @fully_refresh_incremental_tables_enabled
end

#included_tagsArray<String>

Optional. The set of tags to include. Corresponds to the JSON property includedTags

Returns:

  • (Array<String>)


1771
1772
1773
# File 'lib/google/apis/dataform_v1/classes.rb', line 1771

def included_tags
  @included_tags
end

#included_targetsArray<Google::Apis::DataformV1::Target>

Optional. The set of action identifiers to include. Corresponds to the JSON property includedTargets



1776
1777
1778
# File 'lib/google/apis/dataform_v1/classes.rb', line 1776

def included_targets
  @included_targets
end

#query_priorityString

Optional. Specifies the priority for query execution in BigQuery. More information can be found at https://cloud.google.com/bigquery/docs/running- queries#queries. Corresponds to the JSON property queryPriority

Returns:

  • (String)


1783
1784
1785
# File 'lib/google/apis/dataform_v1/classes.rb', line 1783

def query_priority
  @query_priority
end

#service_accountString

Optional. The service account to run workflow invocations under. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


1788
1789
1790
# File 'lib/google/apis/dataform_v1/classes.rb', line 1788

def 
  @service_account
end

#transitive_dependencies_includedBoolean Also known as: transitive_dependencies_included?

Optional. When set to true, transitive dependencies of included actions will be executed. Corresponds to the JSON property transitiveDependenciesIncluded

Returns:

  • (Boolean)


1794
1795
1796
# File 'lib/google/apis/dataform_v1/classes.rb', line 1794

def transitive_dependencies_included
  @transitive_dependencies_included
end

#transitive_dependents_includedBoolean Also known as: transitive_dependents_included?

Optional. When set to true, transitive dependents of included actions will be executed. Corresponds to the JSON property transitiveDependentsIncluded

Returns:

  • (Boolean)


1801
1802
1803
# File 'lib/google/apis/dataform_v1/classes.rb', line 1801

def transitive_dependents_included
  @transitive_dependents_included
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1809
1810
1811
1812
1813
1814
1815
1816
1817
# File 'lib/google/apis/dataform_v1/classes.rb', line 1809

def update!(**args)
  @fully_refresh_incremental_tables_enabled = args[:fully_refresh_incremental_tables_enabled] if args.key?(:fully_refresh_incremental_tables_enabled)
  @included_tags = args[:included_tags] if args.key?(:included_tags)
  @included_targets = args[:included_targets] if args.key?(:included_targets)
  @query_priority = args[:query_priority] if args.key?(:query_priority)
  @service_account = args[:service_account] if args.key?(:service_account)
  @transitive_dependencies_included = args[:transitive_dependencies_included] if args.key?(:transitive_dependencies_included)
  @transitive_dependents_included = args[:transitive_dependents_included] if args.key?(:transitive_dependents_included)
end