Class: Google::Apis::DataformV1::ListOperationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1::ListOperationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb
Overview
The response message for Operations.ListOperations.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The standard List next-page token.
-
#operations ⇒ Array<Google::Apis::DataformV1::Operation>
A list of operations that matches the specified filter in the request.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListOperationsResponse
constructor
A new instance of ListOperationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListOperationsResponse
Returns a new instance of ListOperationsResponse.
1883 1884 1885 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1883 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
The standard List next-page token.
Corresponds to the JSON property nextPageToken
1868 1869 1870 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1868 def next_page_token @next_page_token end |
#operations ⇒ Array<Google::Apis::DataformV1::Operation>
A list of operations that matches the specified filter in the request.
Corresponds to the JSON property operations
1873 1874 1875 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1873 def operations @operations end |
#unreachable ⇒ Array<String>
Unordered list. Unreachable resources. Populated when the request sets
ListOperationsRequest.return_partial_success and reads across collections.
For example, when attempting to list all resources across all supported
locations.
Corresponds to the JSON property unreachable
1881 1882 1883 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1881 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1888 1889 1890 1891 1892 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1888 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @operations = args[:operations] if args.key?(:operations) @unreachable = args[:unreachable] if args.key?(:unreachable) end |