Class: Google::Apis::DataformV1::LoadConfig
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1::LoadConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb
Overview
Simplified load configuration for actions
Instance Attribute Summary collapse
-
#append ⇒ Google::Apis::DataformV1::SimpleLoadMode
Simple load definition Corresponds to the JSON property
append. -
#maximum ⇒ Google::Apis::DataformV1::IncrementalLoadMode
Load definition for incremental load modes Corresponds to the JSON property
maximum. -
#replace ⇒ Google::Apis::DataformV1::SimpleLoadMode
Simple load definition Corresponds to the JSON property
replace. -
#unique ⇒ Google::Apis::DataformV1::IncrementalLoadMode
Load definition for incremental load modes Corresponds to the JSON property
unique.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LoadConfig
constructor
A new instance of LoadConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LoadConfig
Returns a new instance of LoadConfig.
2097 2098 2099 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 2097 def initialize(**args) update!(**args) end |
Instance Attribute Details
#append ⇒ Google::Apis::DataformV1::SimpleLoadMode
Simple load definition
Corresponds to the JSON property append
2080 2081 2082 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 2080 def append @append end |
#maximum ⇒ Google::Apis::DataformV1::IncrementalLoadMode
Load definition for incremental load modes
Corresponds to the JSON property maximum
2085 2086 2087 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 2085 def maximum @maximum end |
#replace ⇒ Google::Apis::DataformV1::SimpleLoadMode
Simple load definition
Corresponds to the JSON property replace
2090 2091 2092 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 2090 def replace @replace end |
#unique ⇒ Google::Apis::DataformV1::IncrementalLoadMode
Load definition for incremental load modes
Corresponds to the JSON property unique
2095 2096 2097 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 2095 def unique @unique end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2102 2103 2104 2105 2106 2107 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 2102 def update!(**args) @append = args[:append] if args.key?(:append) @maximum = args[:maximum] if args.key?(:maximum) @replace = args[:replace] if args.key?(:replace) @unique = args[:unique] if args.key?(:unique) end |