Class: Google::Apis::DataformV1::Location

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb

Overview

A resource that represents a Google Cloud location.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Location

Returns a new instance of Location.



2143
2144
2145
# File 'lib/google/apis/dataform_v1/classes.rb', line 2143

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

The friendly name for this location, typically a nearby city name. For example, "Tokyo". Corresponds to the JSON property displayName

Returns:

  • (String)


2118
2119
2120
# File 'lib/google/apis/dataform_v1/classes.rb', line 2118

def display_name
  @display_name
end

#labelsHash<String,String>

Cross-service attributes for the location. For example "cloud.googleapis.com/ region": "us-east1" Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2124
2125
2126
# File 'lib/google/apis/dataform_v1/classes.rb', line 2124

def labels
  @labels
end

#location_idString

The canonical id for this location. For example: "us-east1". Corresponds to the JSON property locationId

Returns:

  • (String)


2129
2130
2131
# File 'lib/google/apis/dataform_v1/classes.rb', line 2129

def location_id
  @location_id
end

#metadataHash<String,Object>

Service-specific metadata. For example the available capacity at the given location. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Object>)


2135
2136
2137
# File 'lib/google/apis/dataform_v1/classes.rb', line 2135

def 
  @metadata
end

#nameString

Resource name for the location, which may vary between implementations. For example: "projects/example-project/locations/us-east1" Corresponds to the JSON property name

Returns:

  • (String)


2141
2142
2143
# File 'lib/google/apis/dataform_v1/classes.rb', line 2141

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2148
2149
2150
2151
2152
2153
2154
# File 'lib/google/apis/dataform_v1/classes.rb', line 2148

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @labels = args[:labels] if args.key?(:labels)
  @location_id = args[:location_id] if args.key?(:location_id)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
end