Class: Google::Apis::DataformV1::MoveFileRequest
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1::MoveFileRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb
Overview
MoveFile request message.
Instance Attribute Summary collapse
-
#new_path ⇒ String
Required.
-
#path ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MoveFileRequest
constructor
A new instance of MoveFileRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MoveFileRequest
Returns a new instance of MoveFileRequest.
2316 2317 2318 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 2316 def initialize(**args) update!(**args) end |
Instance Attribute Details
#new_path ⇒ String
Required. The file's new path including filename, relative to the workspace
root.
Corresponds to the JSON property newPath
2308 2309 2310 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 2308 def new_path @new_path end |
#path ⇒ String
Required. The file's full path including filename, relative to the workspace
root.
Corresponds to the JSON property path
2314 2315 2316 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 2314 def path @path end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2321 2322 2323 2324 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 2321 def update!(**args) @new_path = args[:new_path] if args.key?(:new_path) @path = args[:path] if args.key?(:path) end |