Class: Google::Apis::DataformV1::Notebook
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1::Notebook
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb
Overview
Represents a notebook.
Instance Attribute Summary collapse
-
#contents ⇒ String
The contents of the notebook.
-
#dependency_targets ⇒ Array<Google::Apis::DataformV1::Target>
A list of actions that this action depends on.
-
#disabled ⇒ Boolean
(also: #disabled?)
Whether this action is disabled (i.e. should not be run).
-
#tags ⇒ Array<String>
Arbitrary, user-defined tags on this action.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Notebook
constructor
A new instance of Notebook.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Notebook
Returns a new instance of Notebook.
2319 2320 2321 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 2319 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contents ⇒ String
The contents of the notebook.
Corresponds to the JSON property contents
2301 2302 2303 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 2301 def contents @contents end |
#dependency_targets ⇒ Array<Google::Apis::DataformV1::Target>
A list of actions that this action depends on.
Corresponds to the JSON property dependencyTargets
2306 2307 2308 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 2306 def dependency_targets @dependency_targets end |
#disabled ⇒ Boolean Also known as: disabled?
Whether this action is disabled (i.e. should not be run).
Corresponds to the JSON property disabled
2311 2312 2313 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 2311 def disabled @disabled end |
#tags ⇒ Array<String>
Arbitrary, user-defined tags on this action.
Corresponds to the JSON property tags
2317 2318 2319 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 2317 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2324 2325 2326 2327 2328 2329 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 2324 def update!(**args) @contents = args[:contents] if args.key?(:contents) @dependency_targets = args[:dependency_targets] if args.key?(:dependency_targets) @disabled = args[:disabled] if args.key?(:disabled) @tags = args[:tags] if args.key?(:tags) end |