Class: Google::Apis::DataformV1::NotebookRuntimeOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb

Overview

Configures various aspects of Dataform notebook runtime.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NotebookRuntimeOptions

Returns a new instance of NotebookRuntimeOptions.



2476
2477
2478
# File 'lib/google/apis/dataform_v1/classes.rb', line 2476

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ai_platform_notebook_runtime_templateString

Optional. The resource name of the Colab runtime template, from which a runtime is created for notebook executions. If not specified, a runtime is created with Colab's default specifications. Corresponds to the JSON property aiPlatformNotebookRuntimeTemplate

Returns:

  • (String)


2463
2464
2465
# File 'lib/google/apis/dataform_v1/classes.rb', line 2463

def ai_platform_notebook_runtime_template
  @ai_platform_notebook_runtime_template
end

#gcs_output_bucketString

Optional. The Google Cloud Storage location to upload the result to. Format: gs://bucket-name. Corresponds to the JSON property gcsOutputBucket

Returns:

  • (String)


2469
2470
2471
# File 'lib/google/apis/dataform_v1/classes.rb', line 2469

def gcs_output_bucket
  @gcs_output_bucket
end

#gcs_repository_snapshot_destinationGoogle::Apis::DataformV1::GcsRepositorySnapshotDestination

Configures the destination for a repository snapshot. Corresponds to the JSON property gcsRepositorySnapshotDestination



2474
2475
2476
# File 'lib/google/apis/dataform_v1/classes.rb', line 2474

def gcs_repository_snapshot_destination
  @gcs_repository_snapshot_destination
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2481
2482
2483
2484
2485
# File 'lib/google/apis/dataform_v1/classes.rb', line 2481

def update!(**args)
  @ai_platform_notebook_runtime_template = args[:ai_platform_notebook_runtime_template] if args.key?(:ai_platform_notebook_runtime_template)
  @gcs_output_bucket = args[:gcs_output_bucket] if args.key?(:gcs_output_bucket)
  @gcs_repository_snapshot_destination = args[:gcs_repository_snapshot_destination] if args.key?(:gcs_repository_snapshot_destination)
end