Class: Google::Apis::DataformV1::Operations
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1::Operations
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb
Overview
Represents a list of arbitrary database operations.
Instance Attribute Summary collapse
-
#dependency_targets ⇒ Array<Google::Apis::DataformV1::Target>
A list of actions that this action depends on.
-
#disabled ⇒ Boolean
(also: #disabled?)
Whether this action is disabled (i.e. should not be run).
-
#has_output ⇒ Boolean
(also: #has_output?)
Whether these operations produce an output relation.
-
#queries ⇒ Array<String>
A list of arbitrary SQL statements that will be executed without alteration.
-
#relation_descriptor ⇒ Google::Apis::DataformV1::RelationDescriptor
Describes a relation and its columns.
-
#tags ⇒ Array<String>
Arbitrary, user-defined tags on this action.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Operations
constructor
A new instance of Operations.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Operations
Returns a new instance of Operations.
2645 2646 2647 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 2645 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dependency_targets ⇒ Array<Google::Apis::DataformV1::Target>
A list of actions that this action depends on.
Corresponds to the JSON property dependencyTargets
2616 2617 2618 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 2616 def dependency_targets @dependency_targets end |
#disabled ⇒ Boolean Also known as: disabled?
Whether this action is disabled (i.e. should not be run).
Corresponds to the JSON property disabled
2621 2622 2623 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 2621 def disabled @disabled end |
#has_output ⇒ Boolean Also known as: has_output?
Whether these operations produce an output relation.
Corresponds to the JSON property hasOutput
2627 2628 2629 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 2627 def has_output @has_output end |
#queries ⇒ Array<String>
A list of arbitrary SQL statements that will be executed without alteration.
Corresponds to the JSON property queries
2633 2634 2635 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 2633 def queries @queries end |
#relation_descriptor ⇒ Google::Apis::DataformV1::RelationDescriptor
Describes a relation and its columns.
Corresponds to the JSON property relationDescriptor
2638 2639 2640 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 2638 def relation_descriptor @relation_descriptor end |
#tags ⇒ Array<String>
Arbitrary, user-defined tags on this action.
Corresponds to the JSON property tags
2643 2644 2645 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 2643 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2650 2651 2652 2653 2654 2655 2656 2657 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 2650 def update!(**args) @dependency_targets = args[:dependency_targets] if args.key?(:dependency_targets) @disabled = args[:disabled] if args.key?(:disabled) @has_output = args[:has_output] if args.key?(:has_output) @queries = args[:queries] if args.key?(:queries) @relation_descriptor = args[:relation_descriptor] if args.key?(:relation_descriptor) @tags = args[:tags] if args.key?(:tags) end |