Class: Google::Apis::DataformV1::PrivateResourceMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb

Overview

Metadata used to identify if a resource is user scoped.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PrivateResourceMetadata

Returns a new instance of PrivateResourceMetadata.



2700
2701
2702
# File 'lib/google/apis/dataform_v1/classes.rb', line 2700

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#user_scopedBoolean Also known as: user_scoped?

Output only. If true, this resource is user-scoped, meaning it is either a workspace or sourced from a workspace. Corresponds to the JSON property userScoped

Returns:

  • (Boolean)


2697
2698
2699
# File 'lib/google/apis/dataform_v1/classes.rb', line 2697

def user_scoped
  @user_scoped
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2705
2706
2707
# File 'lib/google/apis/dataform_v1/classes.rb', line 2705

def update!(**args)
  @user_scoped = args[:user_scoped] if args.key?(:user_scoped)
end