Class: Google::Apis::DataformV1::RelationDescriptor
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1::RelationDescriptor
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb
Overview
Describes a relation and its columns.
Instance Attribute Summary collapse
-
#bigquery_labels ⇒ Hash<String,String>
A set of BigQuery labels that should be applied to the relation.
-
#columns ⇒ Array<Google::Apis::DataformV1::ColumnDescriptor>
A list of descriptions of columns within the relation.
-
#description ⇒ String
A text description of the relation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RelationDescriptor
constructor
A new instance of RelationDescriptor.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RelationDescriptor
Returns a new instance of RelationDescriptor.
3282 3283 3284 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3282 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bigquery_labels ⇒ Hash<String,String>
A set of BigQuery labels that should be applied to the relation.
Corresponds to the JSON property bigqueryLabels
3270 3271 3272 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3270 def bigquery_labels @bigquery_labels end |
#columns ⇒ Array<Google::Apis::DataformV1::ColumnDescriptor>
A list of descriptions of columns within the relation.
Corresponds to the JSON property columns
3275 3276 3277 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3275 def columns @columns end |
#description ⇒ String
A text description of the relation.
Corresponds to the JSON property description
3280 3281 3282 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3280 def description @description end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3287 3288 3289 3290 3291 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3287 def update!(**args) @bigquery_labels = args[:bigquery_labels] if args.key?(:bigquery_labels) @columns = args[:columns] if args.key?(:columns) @description = args[:description] if args.key?(:description) end |