Class: Google::Apis::DataformV1::ResetWorkspaceChangesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb

Overview

ResetWorkspaceChanges request message.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResetWorkspaceChangesRequest

Returns a new instance of ResetWorkspaceChangesRequest.



3573
3574
3575
# File 'lib/google/apis/dataform_v1/classes.rb', line 3573

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cleanBoolean Also known as: clean?

Optional. If set to true, untracked files will be deleted. Corresponds to the JSON property clean

Returns:

  • (Boolean)


3564
3565
3566
# File 'lib/google/apis/dataform_v1/classes.rb', line 3564

def clean
  @clean
end

#pathsArray<String>

Optional. Full file paths to reset back to their committed state including filename, rooted at workspace root. If left empty, all files will be reset. Corresponds to the JSON property paths

Returns:

  • (Array<String>)


3571
3572
3573
# File 'lib/google/apis/dataform_v1/classes.rb', line 3571

def paths
  @paths
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3578
3579
3580
3581
# File 'lib/google/apis/dataform_v1/classes.rb', line 3578

def update!(**args)
  @clean = args[:clean] if args.key?(:clean)
  @paths = args[:paths] if args.key?(:paths)
end