Class: Google::Apis::DataformV1::RootContentsEntry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb

Overview

Represents a single content entry.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RootContentsEntry

Returns a new instance of RootContentsEntry.



3487
3488
3489
# File 'lib/google/apis/dataform_v1/classes.rb', line 3487

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#folderGoogle::Apis::DataformV1::Folder

Represents a Dataform Folder. This is a resource that is used to organize Files and other Folders and provide hierarchical access controls. Corresponds to the JSON property folder



3480
3481
3482
# File 'lib/google/apis/dataform_v1/classes.rb', line 3480

def folder
  @folder
end

#repositoryGoogle::Apis::DataformV1::Repository

Represents a Dataform Git repository. Corresponds to the JSON property repository



3485
3486
3487
# File 'lib/google/apis/dataform_v1/classes.rb', line 3485

def repository
  @repository
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3492
3493
3494
3495
# File 'lib/google/apis/dataform_v1/classes.rb', line 3492

def update!(**args)
  @folder = args[:folder] if args.key?(:folder)
  @repository = args[:repository] if args.key?(:repository)
end