Class: Google::Apis::DataformV1::SqlDefinition
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1::SqlDefinition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb
Overview
Definition of a SQL Data Preparation
Instance Attribute Summary collapse
-
#error_table ⇒ Google::Apis::DataformV1::ErrorTable
Error table information, used to write error data into a BigQuery table.
-
#load ⇒ Google::Apis::DataformV1::LoadConfig
Simplified load configuration for actions Corresponds to the JSON property
load. -
#query ⇒ String
The SQL query representing the data preparation steps.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SqlDefinition
constructor
A new instance of SqlDefinition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SqlDefinition
Returns a new instance of SqlDefinition.
3855 3856 3857 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3855 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_table ⇒ Google::Apis::DataformV1::ErrorTable
Error table information, used to write error data into a BigQuery table.
Corresponds to the JSON property errorTable
3842 3843 3844 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3842 def error_table @error_table end |
#load ⇒ Google::Apis::DataformV1::LoadConfig
Simplified load configuration for actions
Corresponds to the JSON property load
3847 3848 3849 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3847 def load @load end |
#query ⇒ String
The SQL query representing the data preparation steps. Formatted as a Pipe SQL
query statement.
Corresponds to the JSON property query
3853 3854 3855 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3853 def query @query end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3860 3861 3862 3863 3864 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3860 def update!(**args) @error_table = args[:error_table] if args.key?(:error_table) @load = args[:load] if args.key?(:load) @query = args[:query] if args.key?(:query) end |