Class: Google::Apis::DataformV1::TeamFolder
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1::TeamFolder
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb
Overview
Represents a Dataform TeamFolder. This is a resource that sits at the project level and is used to organize Repositories and Folders with hierarchical access controls. They provide a team context and stricter access controls.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#creator_iam_principal ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#internal_metadata ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TeamFolder
constructor
A new instance of TeamFolder.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TeamFolder
Returns a new instance of TeamFolder.
4004 4005 4006 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 4004 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp of when the TeamFolder was created.
Corresponds to the JSON property createTime
3975 3976 3977 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3975 def create_time @create_time end |
#creator_iam_principal ⇒ String
Output only. The IAM principal identifier of the creator of the TeamFolder.
Corresponds to the JSON property creatorIamPrincipal
3980 3981 3982 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3980 def creator_iam_principal @creator_iam_principal end |
#display_name ⇒ String
Required. The TeamFolder's user-friendly name.
Corresponds to the JSON property displayName
3985 3986 3987 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3985 def display_name @display_name end |
#internal_metadata ⇒ String
Output only. All the metadata information that is used internally to serve the
resource. For example: timestamps, flags, status fields, etc. The format of
this field is a JSON string.
Corresponds to the JSON property internalMetadata
3992 3993 3994 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3992 def @internal_metadata end |
#name ⇒ String
Identifier. The TeamFolder's name.
Corresponds to the JSON property name
3997 3998 3999 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3997 def name @name end |
#update_time ⇒ String
Output only. The timestamp of when the TeamFolder was last updated.
Corresponds to the JSON property updateTime
4002 4003 4004 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 4002 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4009 4010 4011 4012 4013 4014 4015 4016 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 4009 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @creator_iam_principal = args[:creator_iam_principal] if args.key?(:creator_iam_principal) @display_name = args[:display_name] if args.key?(:display_name) @internal_metadata = args[:internal_metadata] if args.key?(:internal_metadata) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |