Class: Google::Apis::DataformV1::UncommittedFileChange
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1::UncommittedFileChange
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb
Overview
Represents the Git state of a file with uncommitted changes.
Instance Attribute Summary collapse
-
#path ⇒ String
The file's full path including filename, relative to the workspace root.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UncommittedFileChange
constructor
A new instance of UncommittedFileChange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UncommittedFileChange
Returns a new instance of UncommittedFileChange.
3992 3993 3994 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3992 def initialize(**args) update!(**args) end |
Instance Attribute Details
#path ⇒ String
The file's full path including filename, relative to the workspace root.
Corresponds to the JSON property path
3985 3986 3987 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3985 def path @path end |
#state ⇒ String
Output only. Indicates the status of the file.
Corresponds to the JSON property state
3990 3991 3992 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3990 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3997 3998 3999 4000 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3997 def update!(**args) @path = args[:path] if args.key?(:path) @state = args[:state] if args.key?(:state) end |