Class: Google::Apis::DataformV1::WorkflowConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb

Overview

Represents a Dataform workflow configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkflowConfig

Returns a new instance of WorkflowConfig.



4079
4080
4081
# File 'lib/google/apis/dataform_v1/classes.rb', line 4079

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp of when the WorkflowConfig was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4021
4022
4023
# File 'lib/google/apis/dataform_v1/classes.rb', line 4021

def create_time
  @create_time
end

#cron_scheduleString

Optional. Optional schedule (in cron format) for automatic execution of this workflow config. Corresponds to the JSON property cronSchedule

Returns:

  • (String)


4027
4028
4029
# File 'lib/google/apis/dataform_v1/classes.rb', line 4027

def cron_schedule
  @cron_schedule
end

#disabledBoolean Also known as: disabled?

Optional. Disables automatic creation of workflow invocations. Corresponds to the JSON property disabled

Returns:

  • (Boolean)


4032
4033
4034
# File 'lib/google/apis/dataform_v1/classes.rb', line 4032

def disabled
  @disabled
end

#internal_metadataString

Output only. All the metadata information that is used internally to serve the resource. For example: timestamps, flags, status fields, etc. The format of this field is a JSON string. Corresponds to the JSON property internalMetadata

Returns:

  • (String)


4040
4041
4042
# File 'lib/google/apis/dataform_v1/classes.rb', line 4040

def 
  @internal_metadata
end

#invocation_configGoogle::Apis::DataformV1::InvocationConfig

Includes various configuration options for a workflow invocation. If both included_targets and included_tags are unset, all actions will be included. Corresponds to the JSON property invocationConfig



4046
4047
4048
# File 'lib/google/apis/dataform_v1/classes.rb', line 4046

def invocation_config
  @invocation_config
end

#nameString

Identifier. The workflow config's name. Corresponds to the JSON property name

Returns:

  • (String)


4051
4052
4053
# File 'lib/google/apis/dataform_v1/classes.rb', line 4051

def name
  @name
end

#recent_scheduled_execution_recordsArray<Google::Apis::DataformV1::ScheduledExecutionRecord>

Output only. Records of the 10 most recent scheduled execution attempts, ordered in descending order of execution_time. Updated whenever automatic creation of a workflow invocation is triggered by cron_schedule. Corresponds to the JSON property recentScheduledExecutionRecords



4058
4059
4060
# File 'lib/google/apis/dataform_v1/classes.rb', line 4058

def recent_scheduled_execution_records
  @recent_scheduled_execution_records
end

#release_configString

Required. The name of the release config whose release_compilation_result should be executed. Must be in the format projects/*/locations/*/repositories/ */releaseConfigs/*. Corresponds to the JSON property releaseConfig

Returns:

  • (String)


4065
4066
4067
# File 'lib/google/apis/dataform_v1/classes.rb', line 4065

def release_config
  @release_config
end

#time_zoneString

Optional. Specifies the time zone to be used when interpreting cron_schedule. Must be a time zone name from the time zone database (https://en.wikipedia.org/ wiki/List_of_tz_database_time_zones). If left unspecified, the default is UTC. Corresponds to the JSON property timeZone

Returns:

  • (String)


4072
4073
4074
# File 'lib/google/apis/dataform_v1/classes.rb', line 4072

def time_zone
  @time_zone
end

#update_timeString

Output only. The timestamp of when the WorkflowConfig was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4077
4078
4079
# File 'lib/google/apis/dataform_v1/classes.rb', line 4077

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4084
4085
4086
4087
4088
4089
4090
4091
4092
4093
4094
4095
# File 'lib/google/apis/dataform_v1/classes.rb', line 4084

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @cron_schedule = args[:cron_schedule] if args.key?(:cron_schedule)
  @disabled = args[:disabled] if args.key?(:disabled)
  @internal_metadata = args[:internal_metadata] if args.key?(:internal_metadata)
  @invocation_config = args[:invocation_config] if args.key?(:invocation_config)
  @name = args[:name] if args.key?(:name)
  @recent_scheduled_execution_records = args[:recent_scheduled_execution_records] if args.key?(:recent_scheduled_execution_records)
  @release_config = args[:release_config] if args.key?(:release_config)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
  @update_time = args[:update_time] if args.key?(:update_time)
end