Class: Google::Apis::DataformV1::WorkflowInvocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb

Overview

Represents a single invocation of a compilation result.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkflowInvocation

Returns a new instance of WorkflowInvocation.



4285
4286
4287
# File 'lib/google/apis/dataform_v1/classes.rb', line 4285

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#compilation_resultString

Immutable. The name of the compilation result to use for this invocation. Must be in the format projects/*/locations/*/repositories/*/compilationResults/*. Corresponds to the JSON property compilationResult

Returns:

  • (String)


4224
4225
4226
# File 'lib/google/apis/dataform_v1/classes.rb', line 4224

def compilation_result
  @compilation_result
end

#data_encryption_stateGoogle::Apis::DataformV1::DataEncryptionState

Describes encryption state of a resource. Corresponds to the JSON property dataEncryptionState



4229
4230
4231
# File 'lib/google/apis/dataform_v1/classes.rb', line 4229

def data_encryption_state
  @data_encryption_state
end

#internal_metadataString

Output only. All the metadata information that is used internally to serve the resource. For example: timestamps, flags, status fields, etc. The format of this field is a JSON string. Corresponds to the JSON property internalMetadata

Returns:

  • (String)


4236
4237
4238
# File 'lib/google/apis/dataform_v1/classes.rb', line 4236

def 
  @internal_metadata
end

#invocation_configGoogle::Apis::DataformV1::InvocationConfig

Includes various configuration options for a workflow invocation. If both included_targets and included_tags are unset, all actions will be included. Corresponds to the JSON property invocationConfig



4242
4243
4244
# File 'lib/google/apis/dataform_v1/classes.rb', line 4242

def invocation_config
  @invocation_config
end

#invocation_timingGoogle::Apis::DataformV1::Interval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property invocationTiming



4250
4251
4252
# File 'lib/google/apis/dataform_v1/classes.rb', line 4250

def invocation_timing
  @invocation_timing
end

#nameString

Output only. The workflow invocation's name. Corresponds to the JSON property name

Returns:

  • (String)


4255
4256
4257
# File 'lib/google/apis/dataform_v1/classes.rb', line 4255

def name
  @name
end

#pipeline_configGoogle::Apis::DataformV1::PipelineConfig

Defines the pipeline type and path within the Git repository. Corresponds to the JSON property pipelineConfig



4260
4261
4262
# File 'lib/google/apis/dataform_v1/classes.rb', line 4260

def pipeline_config
  @pipeline_config
end

#private_resource_metadataGoogle::Apis::DataformV1::PrivateResourceMetadata

Metadata used to identify if a resource is user scoped. Corresponds to the JSON property privateResourceMetadata



4265
4266
4267
# File 'lib/google/apis/dataform_v1/classes.rb', line 4265

def 
  @private_resource_metadata
end

#resolved_compilation_resultString

Output only. The resolved compilation result that was used to create this invocation. Will be in the format projects/*/locations/*/repositories/*/ compilationResults/*. Corresponds to the JSON property resolvedCompilationResult

Returns:

  • (String)


4272
4273
4274
# File 'lib/google/apis/dataform_v1/classes.rb', line 4272

def resolved_compilation_result
  @resolved_compilation_result
end

#stateString

Output only. This workflow invocation's current state. Corresponds to the JSON property state

Returns:

  • (String)


4277
4278
4279
# File 'lib/google/apis/dataform_v1/classes.rb', line 4277

def state
  @state
end

#workflow_configString

Immutable. The name of the workflow config to invoke. Must be in the format projects/*/locations/*/repositories/*/workflowConfigs/*. Corresponds to the JSON property workflowConfig

Returns:

  • (String)


4283
4284
4285
# File 'lib/google/apis/dataform_v1/classes.rb', line 4283

def workflow_config
  @workflow_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4290
4291
4292
4293
4294
4295
4296
4297
4298
4299
4300
4301
4302
# File 'lib/google/apis/dataform_v1/classes.rb', line 4290

def update!(**args)
  @compilation_result = args[:compilation_result] if args.key?(:compilation_result)
  @data_encryption_state = args[:data_encryption_state] if args.key?(:data_encryption_state)
  @internal_metadata = args[:internal_metadata] if args.key?(:internal_metadata)
  @invocation_config = args[:invocation_config] if args.key?(:invocation_config)
  @invocation_timing = args[:invocation_timing] if args.key?(:invocation_timing)
  @name = args[:name] if args.key?(:name)
  @pipeline_config = args[:pipeline_config] if args.key?(:pipeline_config)
  @private_resource_metadata = args[:private_resource_metadata] if args.key?(:private_resource_metadata)
  @resolved_compilation_result = args[:resolved_compilation_result] if args.key?(:resolved_compilation_result)
  @state = args[:state] if args.key?(:state)
  @workflow_config = args[:workflow_config] if args.key?(:workflow_config)
end