Class: Google::Apis::DataformV1::FetchGitAheadBehindResponse
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1::FetchGitAheadBehindResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb
Overview
FetchGitAheadBehind response message.
Instance Attribute Summary collapse
-
#commits_ahead ⇒ Fixnum
The number of commits in the remote branch that are not in the workspace.
-
#commits_behind ⇒ Fixnum
The number of commits in the workspace that are not in the remote branch.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FetchGitAheadBehindResponse
constructor
A new instance of FetchGitAheadBehindResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FetchGitAheadBehindResponse
Returns a new instance of FetchGitAheadBehindResponse.
1311 1312 1313 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1311 def initialize(**args) update!(**args) end |
Instance Attribute Details
#commits_ahead ⇒ Fixnum
The number of commits in the remote branch that are not in the workspace.
Corresponds to the JSON property commitsAhead
1304 1305 1306 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1304 def commits_ahead @commits_ahead end |
#commits_behind ⇒ Fixnum
The number of commits in the workspace that are not in the remote branch.
Corresponds to the JSON property commitsBehind
1309 1310 1311 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1309 def commits_behind @commits_behind end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1316 1317 1318 1319 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1316 def update!(**args) @commits_ahead = args[:commits_ahead] if args.key?(:commits_ahead) @commits_behind = args[:commits_behind] if args.key?(:commits_behind) end |