Class: Google::Apis::DataformV1::FilesystemEntryMetadata
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1::FilesystemEntryMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb
Overview
Represents metadata for a single entry in a filesystem.
Instance Attribute Summary collapse
-
#size_bytes ⇒ Fixnum
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FilesystemEntryMetadata
constructor
A new instance of FilesystemEntryMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FilesystemEntryMetadata
Returns a new instance of FilesystemEntryMetadata.
1428 1429 1430 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1428 def initialize(**args) update!(**args) end |
Instance Attribute Details
#size_bytes ⇒ Fixnum
Output only. Provides the size of the entry in bytes. For directories, this
will be 0.
Corresponds to the JSON property sizeBytes
1421 1422 1423 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1421 def size_bytes @size_bytes end |
#update_time ⇒ String
Output only. Represents the time of the last modification of the entry.
Corresponds to the JSON property updateTime
1426 1427 1428 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1426 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1433 1434 1435 1436 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1433 def update!(**args) @size_bytes = args[:size_bytes] if args.key?(:size_bytes) @update_time = args[:update_time] if args.key?(:update_time) end |