Class: Google::Apis::DataformV1::GitRemoteSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb

Overview

Controls Git remote configuration for a repository.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GitRemoteSettings

Returns a new instance of GitRemoteSettings.



1581
1582
1583
# File 'lib/google/apis/dataform_v1/classes.rb', line 1581

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authentication_token_secret_versionString

Optional. The name of the Secret Manager secret version to use as an authentication token for Git operations. Must be in the format projects/*/ secrets/*/versions/*. Corresponds to the JSON property authenticationTokenSecretVersion

Returns:

  • (String)


1544
1545
1546
# File 'lib/google/apis/dataform_v1/classes.rb', line 1544

def authentication_token_secret_version
  @authentication_token_secret_version
end

#default_branchString

Optional. The Git remote's default branch name. If not set, main will be used. Corresponds to the JSON property defaultBranch

Returns:

  • (String)


1550
1551
1552
# File 'lib/google/apis/dataform_v1/classes.rb', line 1550

def default_branch
  @default_branch
end

#effective_default_branchString

Output only. The Git remote's effective default branch name. This is the default branch name of the Git remote if it is set, otherwise it is main. Corresponds to the JSON property effectiveDefaultBranch

Returns:

  • (String)


1556
1557
1558
# File 'lib/google/apis/dataform_v1/classes.rb', line 1556

def effective_default_branch
  @effective_default_branch
end

Optional. Resource name for the GitRepositoryLink used for machine credentials. Must be in the format projects/*/locations/*/connections/*/ gitRepositoryLinks/* Corresponds to the JSON property gitRepositoryLink

Returns:

  • (String)


1563
1564
1565
# File 'lib/google/apis/dataform_v1/classes.rb', line 1563

def git_repository_link
  @git_repository_link
end

#ssh_authentication_configGoogle::Apis::DataformV1::SshAuthenticationConfig

Configures fields for performing SSH authentication. Corresponds to the JSON property sshAuthenticationConfig



1568
1569
1570
# File 'lib/google/apis/dataform_v1/classes.rb', line 1568

def ssh_authentication_config
  @ssh_authentication_config
end

#token_statusString

Output only. Deprecated: The field does not contain any token status information. Corresponds to the JSON property tokenStatus

Returns:

  • (String)


1574
1575
1576
# File 'lib/google/apis/dataform_v1/classes.rb', line 1574

def token_status
  @token_status
end

#urlString

Required. The Git remote's URL. Corresponds to the JSON property url

Returns:

  • (String)


1579
1580
1581
# File 'lib/google/apis/dataform_v1/classes.rb', line 1579

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1586
1587
1588
1589
1590
1591
1592
1593
1594
# File 'lib/google/apis/dataform_v1/classes.rb', line 1586

def update!(**args)
  @authentication_token_secret_version = args[:authentication_token_secret_version] if args.key?(:authentication_token_secret_version)
  @default_branch = args[:default_branch] if args.key?(:default_branch)
  @effective_default_branch = args[:effective_default_branch] if args.key?(:effective_default_branch)
  @git_repository_link = args[:git_repository_link] if args.key?(:git_repository_link)
  @ssh_authentication_config = args[:ssh_authentication_config] if args.key?(:ssh_authentication_config)
  @token_status = args[:token_status] if args.key?(:token_status)
  @url = args[:url] if args.key?(:url)
end