Class: Google::Apis::DataformV1::GitRemoteSettings
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1::GitRemoteSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb
Overview
Controls Git remote configuration for a repository.
Instance Attribute Summary collapse
-
#authentication_token_secret_version ⇒ String
Optional.
-
#default_branch ⇒ String
Optional.
-
#effective_default_branch ⇒ String
Output only.
-
#ssh_authentication_config ⇒ Google::Apis::DataformV1::SshAuthenticationConfig
Configures fields for performing SSH authentication.
-
#token_status ⇒ String
Output only.
-
#url ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GitRemoteSettings
constructor
A new instance of GitRemoteSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GitRemoteSettings
Returns a new instance of GitRemoteSettings.
1573 1574 1575 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1573 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authentication_token_secret_version ⇒ String
Optional. The name of the Secret Manager secret version to use as an
authentication token for Git operations. Must be in the format projects/*/
secrets/*/versions/*.
Corresponds to the JSON property authenticationTokenSecretVersion
1544 1545 1546 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1544 def authentication_token_secret_version @authentication_token_secret_version end |
#default_branch ⇒ String
Optional. The Git remote's default branch name. If not set main will be used.
Corresponds to the JSON property defaultBranch
1549 1550 1551 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1549 def default_branch @default_branch end |
#effective_default_branch ⇒ String
Output only. The Git remote's effective default branch name. This is the
default branch name of the Git remote if it is set, otherwise it is main.
Corresponds to the JSON property effectiveDefaultBranch
1555 1556 1557 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1555 def effective_default_branch @effective_default_branch end |
#ssh_authentication_config ⇒ Google::Apis::DataformV1::SshAuthenticationConfig
Configures fields for performing SSH authentication.
Corresponds to the JSON property sshAuthenticationConfig
1560 1561 1562 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1560 def ssh_authentication_config @ssh_authentication_config end |
#token_status ⇒ String
Output only. Deprecated: The field does not contain any token status
information.
Corresponds to the JSON property tokenStatus
1566 1567 1568 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1566 def token_status @token_status end |
#url ⇒ String
Required. The Git remote's URL.
Corresponds to the JSON property url
1571 1572 1573 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1571 def url @url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1578 1579 1580 1581 1582 1583 1584 1585 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1578 def update!(**args) @authentication_token_secret_version = args[:authentication_token_secret_version] if args.key?(:authentication_token_secret_version) @default_branch = args[:default_branch] if args.key?(:default_branch) @effective_default_branch = args[:effective_default_branch] if args.key?(:effective_default_branch) @ssh_authentication_config = args[:ssh_authentication_config] if args.key?(:ssh_authentication_config) @token_status = args[:token_status] if args.key?(:token_status) @url = args[:url] if args.key?(:url) end |