Class: Google::Apis::DataformV1::IncrementalTableConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb

Overview

Contains settings for relations of type INCREMENTAL_TABLE.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IncrementalTableConfig

Returns a new instance of IncrementalTableConfig.



1687
1688
1689
# File 'lib/google/apis/dataform_v1/classes.rb', line 1687

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#incremental_post_operationsArray<String>

SQL statements to be executed after inserting new rows into the relation. Corresponds to the JSON property incrementalPostOperations

Returns:

  • (Array<String>)


1654
1655
1656
# File 'lib/google/apis/dataform_v1/classes.rb', line 1654

def incremental_post_operations
  @incremental_post_operations
end

#incremental_pre_operationsArray<String>

SQL statements to be executed before inserting new rows into the relation. Corresponds to the JSON property incrementalPreOperations

Returns:

  • (Array<String>)


1659
1660
1661
# File 'lib/google/apis/dataform_v1/classes.rb', line 1659

def incremental_pre_operations
  @incremental_pre_operations
end

#incremental_select_queryString

The SELECT query which returns rows which should be inserted into the relation if it already exists and is not being refreshed. Corresponds to the JSON property incrementalSelectQuery

Returns:

  • (String)


1665
1666
1667
# File 'lib/google/apis/dataform_v1/classes.rb', line 1665

def incremental_select_query
  @incremental_select_query
end

#refresh_disabledBoolean Also known as: refresh_disabled?

Whether this table should be protected from being refreshed. Corresponds to the JSON property refreshDisabled

Returns:

  • (Boolean)


1670
1671
1672
# File 'lib/google/apis/dataform_v1/classes.rb', line 1670

def refresh_disabled
  @refresh_disabled
end

#unique_key_partsArray<String>

A set of columns or SQL expressions used to define row uniqueness. If any duplicates are discovered (as defined by unique_key_parts), only the newly selected rows (as defined by incremental_select_query) will be included in the relation. Corresponds to the JSON property uniqueKeyParts

Returns:

  • (Array<String>)


1679
1680
1681
# File 'lib/google/apis/dataform_v1/classes.rb', line 1679

def unique_key_parts
  @unique_key_parts
end

#update_partition_filterString

A SQL expression conditional used to limit the set of existing rows considered for a merge operation (see unique_key_parts for more information). Corresponds to the JSON property updatePartitionFilter

Returns:

  • (String)


1685
1686
1687
# File 'lib/google/apis/dataform_v1/classes.rb', line 1685

def update_partition_filter
  @update_partition_filter
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1692
1693
1694
1695
1696
1697
1698
1699
# File 'lib/google/apis/dataform_v1/classes.rb', line 1692

def update!(**args)
  @incremental_post_operations = args[:incremental_post_operations] if args.key?(:incremental_post_operations)
  @incremental_pre_operations = args[:incremental_pre_operations] if args.key?(:incremental_pre_operations)
  @incremental_select_query = args[:incremental_select_query] if args.key?(:incremental_select_query)
  @refresh_disabled = args[:refresh_disabled] if args.key?(:refresh_disabled)
  @unique_key_parts = args[:unique_key_parts] if args.key?(:unique_key_parts)
  @update_partition_filter = args[:update_partition_filter] if args.key?(:update_partition_filter)
end