Class: Google::Apis::DataformV1::IncrementalTableConfig
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1::IncrementalTableConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb
Overview
Contains settings for relations of type INCREMENTAL_TABLE.
Instance Attribute Summary collapse
-
#incremental_post_operations ⇒ Array<String>
SQL statements to be executed after inserting new rows into the relation.
-
#incremental_pre_operations ⇒ Array<String>
SQL statements to be executed before inserting new rows into the relation.
-
#incremental_select_query ⇒ String
The SELECT query which returns rows which should be inserted into the relation if it already exists and is not being refreshed.
-
#refresh_disabled ⇒ Boolean
(also: #refresh_disabled?)
Whether this table should be protected from being refreshed.
-
#unique_key_parts ⇒ Array<String>
A set of columns or SQL expressions used to define row uniqueness.
-
#update_partition_filter ⇒ String
A SQL expression conditional used to limit the set of existing rows considered for a merge operation (see
unique_key_partsfor more information).
Instance Method Summary collapse
-
#initialize(**args) ⇒ IncrementalTableConfig
constructor
A new instance of IncrementalTableConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IncrementalTableConfig
Returns a new instance of IncrementalTableConfig.
1670 1671 1672 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1670 def initialize(**args) update!(**args) end |
Instance Attribute Details
#incremental_post_operations ⇒ Array<String>
SQL statements to be executed after inserting new rows into the relation.
Corresponds to the JSON property incrementalPostOperations
1637 1638 1639 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1637 def incremental_post_operations @incremental_post_operations end |
#incremental_pre_operations ⇒ Array<String>
SQL statements to be executed before inserting new rows into the relation.
Corresponds to the JSON property incrementalPreOperations
1642 1643 1644 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1642 def incremental_pre_operations @incremental_pre_operations end |
#incremental_select_query ⇒ String
The SELECT query which returns rows which should be inserted into the relation
if it already exists and is not being refreshed.
Corresponds to the JSON property incrementalSelectQuery
1648 1649 1650 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1648 def incremental_select_query @incremental_select_query end |
#refresh_disabled ⇒ Boolean Also known as: refresh_disabled?
Whether this table should be protected from being refreshed.
Corresponds to the JSON property refreshDisabled
1653 1654 1655 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1653 def refresh_disabled @refresh_disabled end |
#unique_key_parts ⇒ Array<String>
A set of columns or SQL expressions used to define row uniqueness. If any
duplicates are discovered (as defined by unique_key_parts), only the newly
selected rows (as defined by incremental_select_query) will be included in
the relation.
Corresponds to the JSON property uniqueKeyParts
1662 1663 1664 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1662 def unique_key_parts @unique_key_parts end |
#update_partition_filter ⇒ String
A SQL expression conditional used to limit the set of existing rows considered
for a merge operation (see unique_key_parts for more information).
Corresponds to the JSON property updatePartitionFilter
1668 1669 1670 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1668 def update_partition_filter @update_partition_filter end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1675 1676 1677 1678 1679 1680 1681 1682 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 1675 def update!(**args) @incremental_post_operations = args[:incremental_post_operations] if args.key?(:incremental_post_operations) @incremental_pre_operations = args[:incremental_pre_operations] if args.key?(:incremental_pre_operations) @incremental_select_query = args[:incremental_select_query] if args.key?(:incremental_select_query) @refresh_disabled = args[:refresh_disabled] if args.key?(:refresh_disabled) @unique_key_parts = args[:unique_key_parts] if args.key?(:unique_key_parts) @update_partition_filter = args[:update_partition_filter] if args.key?(:update_partition_filter) end |