Class: Google::Apis::DataformV1::MoveFileRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb

Overview

MoveFile request message.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MoveFileRequest

Returns a new instance of MoveFileRequest.



2228
2229
2230
# File 'lib/google/apis/dataform_v1/classes.rb', line 2228

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#new_pathString

Required. The file's new path including filename, relative to the workspace root. Corresponds to the JSON property newPath

Returns:

  • (String)


2220
2221
2222
# File 'lib/google/apis/dataform_v1/classes.rb', line 2220

def new_path
  @new_path
end

#pathString

Required. The file's full path including filename, relative to the workspace root. Corresponds to the JSON property path

Returns:

  • (String)


2226
2227
2228
# File 'lib/google/apis/dataform_v1/classes.rb', line 2226

def path
  @path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2233
2234
2235
2236
# File 'lib/google/apis/dataform_v1/classes.rb', line 2233

def update!(**args)
  @new_path = args[:new_path] if args.key?(:new_path)
  @path = args[:path] if args.key?(:path)
end