Class: Google::Apis::DataformV1::NotebookAction
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1::NotebookAction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb
Overview
Represents a workflow action that will run against a Notebook runtime.
Instance Attribute Summary collapse
-
#contents ⇒ String
Output only.
-
#file_path ⇒ String
Output only.
-
#job_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NotebookAction
constructor
A new instance of NotebookAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NotebookAction
Returns a new instance of NotebookAction.
2441 2442 2443 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 2441 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contents ⇒ String
Output only. The code contents of a Notebook to be run.
Corresponds to the JSON property contents
2427 2428 2429 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 2427 def contents @contents end |
#file_path ⇒ String
Output only. The path to the notebook file in the repository.
Corresponds to the JSON property filePath
2432 2433 2434 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 2432 def file_path @file_path end |
#job_id ⇒ String
Output only. The ID of the Gemini Enterprise Agent Platform job that executed
the notebook in contents and also the ID used for the outputs created in
Google Cloud Storage buckets. Only set once the job has started to run.
Corresponds to the JSON property jobId
2439 2440 2441 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 2439 def job_id @job_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2446 2447 2448 2449 2450 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 2446 def update!(**args) @contents = args[:contents] if args.key?(:contents) @file_path = args[:file_path] if args.key?(:file_path) @job_id = args[:job_id] if args.key?(:job_id) end |