Class: Google::Apis::DataformV1::NotebookAction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb

Overview

Represents a workflow action that will run against a Notebook runtime.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NotebookAction

Returns a new instance of NotebookAction.



2348
2349
2350
# File 'lib/google/apis/dataform_v1/classes.rb', line 2348

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentsString

Output only. The code contents of a Notebook to be run. Corresponds to the JSON property contents

Returns:

  • (String)


2339
2340
2341
# File 'lib/google/apis/dataform_v1/classes.rb', line 2339

def contents
  @contents
end

#job_idString

Output only. The ID of the Vertex job that executed the notebook in contents and also the ID used for the outputs created in Google Cloud Storage buckets. Only set once the job has started to run. Corresponds to the JSON property jobId

Returns:

  • (String)


2346
2347
2348
# File 'lib/google/apis/dataform_v1/classes.rb', line 2346

def job_id
  @job_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2353
2354
2355
2356
# File 'lib/google/apis/dataform_v1/classes.rb', line 2353

def update!(**args)
  @contents = args[:contents] if args.key?(:contents)
  @job_id = args[:job_id] if args.key?(:job_id)
end