Class: Google::Apis::DataformV1::NotebookRuntimeOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb

Overview

Configures various aspects of Dataform notebook runtime.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NotebookRuntimeOptions

Returns a new instance of NotebookRuntimeOptions.



2387
2388
2389
# File 'lib/google/apis/dataform_v1/classes.rb', line 2387

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ai_platform_notebook_runtime_templateString

Optional. The resource name of the Colab runtime template, from which a runtime is created for notebook executions. If not specified, a runtime is created with Colab's default specifications. Corresponds to the JSON property aiPlatformNotebookRuntimeTemplate

Returns:

  • (String)


2379
2380
2381
# File 'lib/google/apis/dataform_v1/classes.rb', line 2379

def ai_platform_notebook_runtime_template
  @ai_platform_notebook_runtime_template
end

#gcs_output_bucketString

Optional. The Google Cloud Storage location to upload the result to. Format: gs://bucket-name. Corresponds to the JSON property gcsOutputBucket

Returns:

  • (String)


2385
2386
2387
# File 'lib/google/apis/dataform_v1/classes.rb', line 2385

def gcs_output_bucket
  @gcs_output_bucket
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2392
2393
2394
2395
# File 'lib/google/apis/dataform_v1/classes.rb', line 2392

def update!(**args)
  @ai_platform_notebook_runtime_template = args[:ai_platform_notebook_runtime_template] if args.key?(:ai_platform_notebook_runtime_template)
  @gcs_output_bucket = args[:gcs_output_bucket] if args.key?(:gcs_output_bucket)
end