Class: Google::Apis::DataformV1::ReleaseConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb

Overview

Represents a Dataform release configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReleaseConfig

Returns a new instance of ReleaseConfig.



3249
3250
3251
# File 'lib/google/apis/dataform_v1/classes.rb', line 3249

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#code_compilation_configGoogle::Apis::DataformV1::CodeCompilationConfig

Configures various aspects of Dataform code compilation. Corresponds to the JSON property codeCompilationConfig



3191
3192
3193
# File 'lib/google/apis/dataform_v1/classes.rb', line 3191

def code_compilation_config
  @code_compilation_config
end

#cron_scheduleString

Optional. Optional schedule (in cron format) for automatic creation of compilation results. Corresponds to the JSON property cronSchedule

Returns:

  • (String)


3197
3198
3199
# File 'lib/google/apis/dataform_v1/classes.rb', line 3197

def cron_schedule
  @cron_schedule
end

#disabledBoolean Also known as: disabled?

Optional. Disables automatic creation of compilation results. Corresponds to the JSON property disabled

Returns:

  • (Boolean)


3202
3203
3204
# File 'lib/google/apis/dataform_v1/classes.rb', line 3202

def disabled
  @disabled
end

#git_commitishString

Required. Git commit/tag/branch name at which the repository should be compiled. Must exist in the remote repository. Examples: - a commit SHA: 12ade345 - a tag: tag1 - a branch name: branch1 Corresponds to the JSON property gitCommitish

Returns:

  • (String)


3210
3211
3212
# File 'lib/google/apis/dataform_v1/classes.rb', line 3210

def git_commitish
  @git_commitish
end

#internal_metadataString

Output only. All the metadata information that is used internally to serve the resource. For example: timestamps, flags, status fields, etc. The format of this field is a JSON string. Corresponds to the JSON property internalMetadata

Returns:

  • (String)


3217
3218
3219
# File 'lib/google/apis/dataform_v1/classes.rb', line 3217

def 
  @internal_metadata
end

#nameString

Identifier. The release config's name. Corresponds to the JSON property name

Returns:

  • (String)


3222
3223
3224
# File 'lib/google/apis/dataform_v1/classes.rb', line 3222

def name
  @name
end

#recent_scheduled_release_recordsArray<Google::Apis::DataformV1::ScheduledReleaseRecord>

Output only. Records of the 10 most recent scheduled release attempts, ordered in descending order of release_time. Updated whenever automatic creation of a compilation result is triggered by cron_schedule. Corresponds to the JSON property recentScheduledReleaseRecords



3229
3230
3231
# File 'lib/google/apis/dataform_v1/classes.rb', line 3229

def recent_scheduled_release_records
  @recent_scheduled_release_records
end

#release_compilation_resultString

Optional. The name of the currently released compilation result for this release config. This value is updated when a compilation result is automatically created from this release config (using cron_schedule), or when this resource is updated by API call (perhaps to roll back to an earlier release). The compilation result must have been created using this release config. Must be in the format projects/*/locations/*/repositories/*/ compilationResults/*. Corresponds to the JSON property releaseCompilationResult

Returns:

  • (String)


3240
3241
3242
# File 'lib/google/apis/dataform_v1/classes.rb', line 3240

def release_compilation_result
  @release_compilation_result
end

#time_zoneString

Optional. Specifies the time zone to be used when interpreting cron_schedule. Must be a time zone name from the time zone database (https://en.wikipedia.org/ wiki/List_of_tz_database_time_zones). If left unspecified, the default is UTC. Corresponds to the JSON property timeZone

Returns:

  • (String)


3247
3248
3249
# File 'lib/google/apis/dataform_v1/classes.rb', line 3247

def time_zone
  @time_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3254
3255
3256
3257
3258
3259
3260
3261
3262
3263
3264
# File 'lib/google/apis/dataform_v1/classes.rb', line 3254

def update!(**args)
  @code_compilation_config = args[:code_compilation_config] if args.key?(:code_compilation_config)
  @cron_schedule = args[:cron_schedule] if args.key?(:cron_schedule)
  @disabled = args[:disabled] if args.key?(:disabled)
  @git_commitish = args[:git_commitish] if args.key?(:git_commitish)
  @internal_metadata = args[:internal_metadata] if args.key?(:internal_metadata)
  @name = args[:name] if args.key?(:name)
  @recent_scheduled_release_records = args[:recent_scheduled_release_records] if args.key?(:recent_scheduled_release_records)
  @release_compilation_result = args[:release_compilation_result] if args.key?(:release_compilation_result)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
end