Class: Google::Apis::DataformV1::Repository

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb

Overview

Represents a Dataform Git repository.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Repository

Returns a new instance of Repository.



3425
3426
3427
# File 'lib/google/apis/dataform_v1/classes.rb', line 3425

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#containing_folderString

Optional. The name of the containing folder of the repository. The field is immutable and it can be modified via a MoveRepository operation. Format: projects/*/locations/*/folders/*. or projects/*/locations/*/teamFolders/*. Corresponds to the JSON property containingFolder

Returns:

  • (String)


3344
3345
3346
# File 'lib/google/apis/dataform_v1/classes.rb', line 3344

def containing_folder
  @containing_folder
end

#create_timeString

Output only. The timestamp of when the repository was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3349
3350
3351
# File 'lib/google/apis/dataform_v1/classes.rb', line 3349

def create_time
  @create_time
end

#data_encryption_stateGoogle::Apis::DataformV1::DataEncryptionState

Describes encryption state of a resource. Corresponds to the JSON property dataEncryptionState



3354
3355
3356
# File 'lib/google/apis/dataform_v1/classes.rb', line 3354

def data_encryption_state
  @data_encryption_state
end

#display_nameString

Optional. The repository's user-friendly name. Corresponds to the JSON property displayName

Returns:

  • (String)


3359
3360
3361
# File 'lib/google/apis/dataform_v1/classes.rb', line 3359

def display_name
  @display_name
end

#git_remote_settingsGoogle::Apis::DataformV1::GitRemoteSettings

Controls Git remote configuration for a repository. Corresponds to the JSON property gitRemoteSettings



3364
3365
3366
# File 'lib/google/apis/dataform_v1/classes.rb', line 3364

def git_remote_settings
  @git_remote_settings
end

#internal_metadataString

Output only. All the metadata information that is used internally to serve the resource. For example: timestamps, flags, status fields, etc. The format of this field is a JSON string. Corresponds to the JSON property internalMetadata

Returns:

  • (String)


3371
3372
3373
# File 'lib/google/apis/dataform_v1/classes.rb', line 3371

def 
  @internal_metadata
end

#kms_key_nameString

Optional. The reference to a KMS encryption key. If provided, it will be used to encrypt user data in the repository and all child resources. It is not possible to add or update the encryption key after the repository is created. Example: projects/kms_project/locations/location/keyRings/key_location/ cryptoKeys/key` Corresponds to the JSON propertykmsKeyName`

Returns:

  • (String)


3380
3381
3382
# File 'lib/google/apis/dataform_v1/classes.rb', line 3380

def kms_key_name
  @kms_key_name
end

#labelsHash<String,String>

Optional. Repository user labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3385
3386
3387
# File 'lib/google/apis/dataform_v1/classes.rb', line 3385

def labels
  @labels
end

#nameString

Identifier. The repository's name. Corresponds to the JSON property name

Returns:

  • (String)


3390
3391
3392
# File 'lib/google/apis/dataform_v1/classes.rb', line 3390

def name
  @name
end

#npmrc_environment_variables_secret_versionString

Optional. The name of the Secret Manager secret version to be used to interpolate variables into the .npmrc file for package installation operations. Must be in the format projects/*/secrets/*/versions/*. The file itself must be in a JSON format. Corresponds to the JSON property npmrcEnvironmentVariablesSecretVersion

Returns:

  • (String)


3398
3399
3400
# File 'lib/google/apis/dataform_v1/classes.rb', line 3398

def npmrc_environment_variables_secret_version
  @npmrc_environment_variables_secret_version
end

#service_accountString

Optional. The service account to run workflow invocations under. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


3403
3404
3405
# File 'lib/google/apis/dataform_v1/classes.rb', line 3403

def 
  @service_account
end

#set_authenticated_user_adminBoolean Also known as: set_authenticated_user_admin?

Optional. Input only. If set to true, the authenticated user will be granted the roles/dataform.admin role on the created repository. Corresponds to the JSON property setAuthenticatedUserAdmin

Returns:

  • (Boolean)


3409
3410
3411
# File 'lib/google/apis/dataform_v1/classes.rb', line 3409

def set_authenticated_user_admin
  @set_authenticated_user_admin
end

#team_folder_nameString

Output only. The resource name of the TeamFolder that this Repository is associated with. This should take the format: projects/project/locations/ location/teamFolders/teamFolder. If this is not set, the Repository is not associated with a TeamFolder. Corresponds to the JSON property teamFolderName

Returns:

  • (String)


3418
3419
3420
# File 'lib/google/apis/dataform_v1/classes.rb', line 3418

def team_folder_name
  @team_folder_name
end

#workspace_compilation_overridesGoogle::Apis::DataformV1::WorkspaceCompilationOverrides

Configures workspace compilation overrides for a repository. Corresponds to the JSON property workspaceCompilationOverrides



3423
3424
3425
# File 'lib/google/apis/dataform_v1/classes.rb', line 3423

def workspace_compilation_overrides
  @workspace_compilation_overrides
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3430
3431
3432
3433
3434
3435
3436
3437
3438
3439
3440
3441
3442
3443
3444
3445
# File 'lib/google/apis/dataform_v1/classes.rb', line 3430

def update!(**args)
  @containing_folder = args[:containing_folder] if args.key?(:containing_folder)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_encryption_state = args[:data_encryption_state] if args.key?(:data_encryption_state)
  @display_name = args[:display_name] if args.key?(:display_name)
  @git_remote_settings = args[:git_remote_settings] if args.key?(:git_remote_settings)
  @internal_metadata = args[:internal_metadata] if args.key?(:internal_metadata)
  @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @npmrc_environment_variables_secret_version = args[:npmrc_environment_variables_secret_version] if args.key?(:npmrc_environment_variables_secret_version)
  @service_account = args[:service_account] if args.key?(:service_account)
  @set_authenticated_user_admin = args[:set_authenticated_user_admin] if args.key?(:set_authenticated_user_admin)
  @team_folder_name = args[:team_folder_name] if args.key?(:team_folder_name)
  @workspace_compilation_overrides = args[:workspace_compilation_overrides] if args.key?(:workspace_compilation_overrides)
end