Class: Google::Apis::DataformV1::ResetWorkspaceChangesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb

Overview

ResetWorkspaceChanges request message.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResetWorkspaceChangesRequest

Returns a new instance of ResetWorkspaceChangesRequest.



3464
3465
3466
# File 'lib/google/apis/dataform_v1/classes.rb', line 3464

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cleanBoolean Also known as: clean?

Optional. If set to true, untracked files will be deleted. Corresponds to the JSON property clean

Returns:

  • (Boolean)


3455
3456
3457
# File 'lib/google/apis/dataform_v1/classes.rb', line 3455

def clean
  @clean
end

#pathsArray<String>

Optional. Full file paths to reset back to their committed state including filename, rooted at workspace root. If left empty, all files will be reset. Corresponds to the JSON property paths

Returns:

  • (Array<String>)


3462
3463
3464
# File 'lib/google/apis/dataform_v1/classes.rb', line 3462

def paths
  @paths
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3469
3470
3471
3472
# File 'lib/google/apis/dataform_v1/classes.rb', line 3469

def update!(**args)
  @clean = args[:clean] if args.key?(:clean)
  @paths = args[:paths] if args.key?(:paths)
end