Class: Google::Apis::DataformV1::ResetWorkspaceChangesRequest
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1::ResetWorkspaceChangesRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb
Overview
ResetWorkspaceChanges request message.
Instance Attribute Summary collapse
-
#clean ⇒ Boolean
(also: #clean?)
Optional.
-
#paths ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResetWorkspaceChangesRequest
constructor
A new instance of ResetWorkspaceChangesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResetWorkspaceChangesRequest
Returns a new instance of ResetWorkspaceChangesRequest.
3445 3446 3447 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3445 def initialize(**args) update!(**args) end |
Instance Attribute Details
#clean ⇒ Boolean Also known as: clean?
Optional. If set to true, untracked files will be deleted.
Corresponds to the JSON property clean
3436 3437 3438 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3436 def clean @clean end |
#paths ⇒ Array<String>
Optional. Full file paths to reset back to their committed state including
filename, rooted at workspace root. If left empty, all files will be reset.
Corresponds to the JSON property paths
3443 3444 3445 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3443 def paths @paths end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3450 3451 3452 3453 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3450 def update!(**args) @clean = args[:clean] if args.key?(:clean) @paths = args[:paths] if args.key?(:paths) end |