Class: Google::Apis::DataformV1::RootContentsEntry
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1::RootContentsEntry
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb
Overview
Represents a single content entry.
Instance Attribute Summary collapse
-
#folder ⇒ Google::Apis::DataformV1::Folder
Represents a Dataform Folder.
-
#repository ⇒ Google::Apis::DataformV1::Repository
Represents a Dataform Git repository.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RootContentsEntry
constructor
A new instance of RootContentsEntry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RootContentsEntry
Returns a new instance of RootContentsEntry.
3484 3485 3486 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3484 def initialize(**args) update!(**args) end |
Instance Attribute Details
#folder ⇒ Google::Apis::DataformV1::Folder
Represents a Dataform Folder. This is a resource that is used to organize
Files and other Folders and provide hierarchical access controls.
Corresponds to the JSON property folder
3477 3478 3479 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3477 def folder @folder end |
#repository ⇒ Google::Apis::DataformV1::Repository
Represents a Dataform Git repository.
Corresponds to the JSON property repository
3482 3483 3484 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3482 def repository @repository end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3489 3490 3491 3492 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3489 def update!(**args) @folder = args[:folder] if args.key?(:folder) @repository = args[:repository] if args.key?(:repository) end |