Class: Google::Apis::DataformV1::ScheduledReleaseRecord
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1::ScheduledReleaseRecord
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb
Overview
A record of an attempt to create a compilation result for this release config.
Instance Attribute Summary collapse
-
#compilation_result ⇒ String
The name of the created compilation result, if one was successfully created.
-
#error_status ⇒ Google::Apis::DataformV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#release_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ScheduledReleaseRecord
constructor
A new instance of ScheduledReleaseRecord.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ScheduledReleaseRecord
Returns a new instance of ScheduledReleaseRecord.
3563 3564 3565 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3563 def initialize(**args) update!(**args) end |
Instance Attribute Details
#compilation_result ⇒ String
The name of the created compilation result, if one was successfully created.
Must be in the format projects/*/locations/*/repositories/*/
compilationResults/*.
Corresponds to the JSON property compilationResult
3546 3547 3548 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3546 def compilation_result @compilation_result end |
#error_status ⇒ Google::Apis::DataformV1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property errorStatus
3556 3557 3558 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3556 def error_status @error_status end |
#release_time ⇒ String
Output only. The timestamp of this release attempt.
Corresponds to the JSON property releaseTime
3561 3562 3563 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3561 def release_time @release_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3568 3569 3570 3571 3572 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3568 def update!(**args) @compilation_result = args[:compilation_result] if args.key?(:compilation_result) @error_status = args[:error_status] if args.key?(:error_status) @release_time = args[:release_time] if args.key?(:release_time) end |