Class: Google::Apis::DataformV1::SqlDefinition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb

Overview

Definition of a SQL Data Preparation

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SqlDefinition

Returns a new instance of SqlDefinition.



3746
3747
3748
# File 'lib/google/apis/dataform_v1/classes.rb', line 3746

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_tableGoogle::Apis::DataformV1::ErrorTable

Error table information, used to write error data into a BigQuery table. Corresponds to the JSON property errorTable



3733
3734
3735
# File 'lib/google/apis/dataform_v1/classes.rb', line 3733

def error_table
  @error_table
end

#loadGoogle::Apis::DataformV1::LoadConfig

Simplified load configuration for actions Corresponds to the JSON property load



3738
3739
3740
# File 'lib/google/apis/dataform_v1/classes.rb', line 3738

def load
  @load
end

#queryString

The SQL query representing the data preparation steps. Formatted as a Pipe SQL query statement. Corresponds to the JSON property query

Returns:

  • (String)


3744
3745
3746
# File 'lib/google/apis/dataform_v1/classes.rb', line 3744

def query
  @query
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3751
3752
3753
3754
3755
# File 'lib/google/apis/dataform_v1/classes.rb', line 3751

def update!(**args)
  @error_table = args[:error_table] if args.key?(:error_table)
  @load = args[:load] if args.key?(:load)
  @query = args[:query] if args.key?(:query)
end