Class: Google::Apis::DataformV1::SqlDefinition
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1::SqlDefinition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb
Overview
Definition of a SQL Data Preparation
Instance Attribute Summary collapse
-
#error_table ⇒ Google::Apis::DataformV1::ErrorTable
Error table information, used to write error data into a BigQuery table.
-
#load ⇒ Google::Apis::DataformV1::LoadConfig
Simplified load configuration for actions Corresponds to the JSON property
load. -
#query ⇒ String
The SQL query representing the data preparation steps.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SqlDefinition
constructor
A new instance of SqlDefinition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SqlDefinition
Returns a new instance of SqlDefinition.
3730 3731 3732 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3730 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_table ⇒ Google::Apis::DataformV1::ErrorTable
Error table information, used to write error data into a BigQuery table.
Corresponds to the JSON property errorTable
3717 3718 3719 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3717 def error_table @error_table end |
#load ⇒ Google::Apis::DataformV1::LoadConfig
Simplified load configuration for actions
Corresponds to the JSON property load
3722 3723 3724 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3722 def load @load end |
#query ⇒ String
The SQL query representing the data preparation steps. Formatted as a Pipe SQL
query statement.
Corresponds to the JSON property query
3728 3729 3730 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3728 def query @query end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3735 3736 3737 3738 3739 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3735 def update!(**args) @error_table = args[:error_table] if args.key?(:error_table) @load = args[:load] if args.key?(:load) @query = args[:query] if args.key?(:query) end |