Class: Google::Apis::DataformV1::SqlDefinition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb

Overview

Definition of a SQL Data Preparation

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SqlDefinition

Returns a new instance of SqlDefinition.



3727
3728
3729
# File 'lib/google/apis/dataform_v1/classes.rb', line 3727

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_tableGoogle::Apis::DataformV1::ErrorTable

Error table information, used to write error data into a BigQuery table. Corresponds to the JSON property errorTable



3714
3715
3716
# File 'lib/google/apis/dataform_v1/classes.rb', line 3714

def error_table
  @error_table
end

#loadGoogle::Apis::DataformV1::LoadConfig

Simplified load configuration for actions Corresponds to the JSON property load



3719
3720
3721
# File 'lib/google/apis/dataform_v1/classes.rb', line 3719

def load
  @load
end

#queryString

The SQL query representing the data preparation steps. Formatted as a Pipe SQL query statement. Corresponds to the JSON property query

Returns:

  • (String)


3725
3726
3727
# File 'lib/google/apis/dataform_v1/classes.rb', line 3725

def query
  @query
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3732
3733
3734
3735
3736
# File 'lib/google/apis/dataform_v1/classes.rb', line 3732

def update!(**args)
  @error_table = args[:error_table] if args.key?(:error_table)
  @load = args[:load] if args.key?(:load)
  @query = args[:query] if args.key?(:query)
end