Class: Google::Apis::DataformV1::SshAuthenticationConfig
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1::SshAuthenticationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb
Overview
Configures fields for performing SSH authentication.
Instance Attribute Summary collapse
-
#host_public_key ⇒ String
Required.
-
#user_private_key_secret_version ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SshAuthenticationConfig
constructor
A new instance of SshAuthenticationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SshAuthenticationConfig
Returns a new instance of SshAuthenticationConfig.
3756 3757 3758 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3756 def initialize(**args) update!(**args) end |
Instance Attribute Details
#host_public_key ⇒ String
Required. Content of a public SSH key to verify an identity of a remote Git
host.
Corresponds to the JSON property hostPublicKey
3747 3748 3749 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3747 def host_public_key @host_public_key end |
#user_private_key_secret_version ⇒ String
Required. The name of the Secret Manager secret version to use as a ssh
private key for Git operations. Must be in the format projects/*/secrets/*/
versions/*.
Corresponds to the JSON property userPrivateKeySecretVersion
3754 3755 3756 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3754 def user_private_key_secret_version @user_private_key_secret_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3761 3762 3763 3764 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3761 def update!(**args) @host_public_key = args[:host_public_key] if args.key?(:host_public_key) @user_private_key_secret_version = args[:user_private_key_secret_version] if args.key?(:user_private_key_secret_version) end |