Class: Google::Apis::DataformV1::TeamFolder

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb

Overview

Represents a Dataform TeamFolder. This is a resource that sits at the project level and is used to organize Repositories and Folders with hierarchical access controls. They provide a team context and stricter access controls.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TeamFolder

Returns a new instance of TeamFolder.



3887
3888
3889
# File 'lib/google/apis/dataform_v1/classes.rb', line 3887

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp of when the TeamFolder was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3858
3859
3860
# File 'lib/google/apis/dataform_v1/classes.rb', line 3858

def create_time
  @create_time
end

#creator_iam_principalString

Output only. The IAM principal identifier of the creator of the TeamFolder. Corresponds to the JSON property creatorIamPrincipal

Returns:

  • (String)


3863
3864
3865
# File 'lib/google/apis/dataform_v1/classes.rb', line 3863

def creator_iam_principal
  @creator_iam_principal
end

#display_nameString

Required. The TeamFolder's user-friendly name. Corresponds to the JSON property displayName

Returns:

  • (String)


3868
3869
3870
# File 'lib/google/apis/dataform_v1/classes.rb', line 3868

def display_name
  @display_name
end

#internal_metadataString

Output only. All the metadata information that is used internally to serve the resource. For example: timestamps, flags, status fields, etc. The format of this field is a JSON string. Corresponds to the JSON property internalMetadata

Returns:

  • (String)


3875
3876
3877
# File 'lib/google/apis/dataform_v1/classes.rb', line 3875

def 
  @internal_metadata
end

#nameString

Identifier. The TeamFolder's name. Corresponds to the JSON property name

Returns:

  • (String)


3880
3881
3882
# File 'lib/google/apis/dataform_v1/classes.rb', line 3880

def name
  @name
end

#update_timeString

Output only. The timestamp of when the TeamFolder was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


3885
3886
3887
# File 'lib/google/apis/dataform_v1/classes.rb', line 3885

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3892
3893
3894
3895
3896
3897
3898
3899
# File 'lib/google/apis/dataform_v1/classes.rb', line 3892

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @creator_iam_principal = args[:creator_iam_principal] if args.key?(:creator_iam_principal)
  @display_name = args[:display_name] if args.key?(:display_name)
  @internal_metadata = args[:internal_metadata] if args.key?(:internal_metadata)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end