Class: Google::Apis::DataformV1::TeamFolderContentsEntry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb

Overview

Represents a single content entry.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TeamFolderContentsEntry

Returns a new instance of TeamFolderContentsEntry.



3909
3910
3911
# File 'lib/google/apis/dataform_v1/classes.rb', line 3909

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#folderGoogle::Apis::DataformV1::Folder

Represents a Dataform Folder. This is a resource that is used to organize Files and other Folders and provide hierarchical access controls. Corresponds to the JSON property folder



3902
3903
3904
# File 'lib/google/apis/dataform_v1/classes.rb', line 3902

def folder
  @folder
end

#repositoryGoogle::Apis::DataformV1::Repository

Represents a Dataform Git repository. Corresponds to the JSON property repository



3907
3908
3909
# File 'lib/google/apis/dataform_v1/classes.rb', line 3907

def repository
  @repository
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3914
3915
3916
3917
# File 'lib/google/apis/dataform_v1/classes.rb', line 3914

def update!(**args)
  @folder = args[:folder] if args.key?(:folder)
  @repository = args[:repository] if args.key?(:repository)
end