Class: Google::Apis::DataformV1::TeamFolderContentsEntry
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1::TeamFolderContentsEntry
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb
Overview
Represents a single content entry.
Instance Attribute Summary collapse
-
#folder ⇒ Google::Apis::DataformV1::Folder
Represents a Dataform Folder.
-
#repository ⇒ Google::Apis::DataformV1::Repository
Represents a Dataform Git repository.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TeamFolderContentsEntry
constructor
A new instance of TeamFolderContentsEntry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TeamFolderContentsEntry
Returns a new instance of TeamFolderContentsEntry.
3906 3907 3908 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3906 def initialize(**args) update!(**args) end |
Instance Attribute Details
#folder ⇒ Google::Apis::DataformV1::Folder
Represents a Dataform Folder. This is a resource that is used to organize
Files and other Folders and provide hierarchical access controls.
Corresponds to the JSON property folder
3899 3900 3901 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3899 def folder @folder end |
#repository ⇒ Google::Apis::DataformV1::Repository
Represents a Dataform Git repository.
Corresponds to the JSON property repository
3904 3905 3906 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3904 def repository @repository end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3911 3912 3913 3914 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 3911 def update!(**args) @folder = args[:folder] if args.key?(:folder) @repository = args[:repository] if args.key?(:repository) end |