Class: Google::Apis::DataformV1::WorkflowInvocation
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1::WorkflowInvocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb
Overview
Represents a single invocation of a compilation result.
Instance Attribute Summary collapse
-
#compilation_result ⇒ String
Immutable.
-
#data_encryption_state ⇒ Google::Apis::DataformV1::DataEncryptionState
Describes encryption state of a resource.
-
#internal_metadata ⇒ String
Output only.
-
#invocation_config ⇒ Google::Apis::DataformV1::InvocationConfig
Includes various configuration options for a workflow invocation.
-
#invocation_timing ⇒ Google::Apis::DataformV1::Interval
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive).
-
#name ⇒ String
Output only.
-
#private_resource_metadata ⇒ Google::Apis::DataformV1::PrivateResourceMetadata
Metadata used to identify if a resource is user scoped.
-
#resolved_compilation_result ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#workflow_config ⇒ String
Immutable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkflowInvocation
constructor
A new instance of WorkflowInvocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkflowInvocation
Returns a new instance of WorkflowInvocation.
4151 4152 4153 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 4151 def initialize(**args) update!(**args) end |
Instance Attribute Details
#compilation_result ⇒ String
Immutable. The name of the compilation result to use for this invocation. Must
be in the format projects/*/locations/*/repositories/*/compilationResults/*.
Corresponds to the JSON property compilationResult
4095 4096 4097 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 4095 def compilation_result @compilation_result end |
#data_encryption_state ⇒ Google::Apis::DataformV1::DataEncryptionState
Describes encryption state of a resource.
Corresponds to the JSON property dataEncryptionState
4100 4101 4102 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 4100 def data_encryption_state @data_encryption_state end |
#internal_metadata ⇒ String
Output only. All the metadata information that is used internally to serve the
resource. For example: timestamps, flags, status fields, etc. The format of
this field is a JSON string.
Corresponds to the JSON property internalMetadata
4107 4108 4109 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 4107 def @internal_metadata end |
#invocation_config ⇒ Google::Apis::DataformV1::InvocationConfig
Includes various configuration options for a workflow invocation. If both
included_targets and included_tags are unset, all actions will be included.
Corresponds to the JSON property invocationConfig
4113 4114 4115 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 4113 def invocation_config @invocation_config end |
#invocation_timing ⇒ Google::Apis::DataformV1::Interval
Represents a time interval, encoded as a Timestamp start (inclusive) and a
Timestamp end (exclusive). The start must be less than or equal to the end.
When the start equals the end, the interval is empty (matches no time). When
both start and end are unspecified, the interval matches any time.
Corresponds to the JSON property invocationTiming
4121 4122 4123 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 4121 def invocation_timing @invocation_timing end |
#name ⇒ String
Output only. The workflow invocation's name.
Corresponds to the JSON property name
4126 4127 4128 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 4126 def name @name end |
#private_resource_metadata ⇒ Google::Apis::DataformV1::PrivateResourceMetadata
Metadata used to identify if a resource is user scoped.
Corresponds to the JSON property privateResourceMetadata
4131 4132 4133 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 4131 def @private_resource_metadata end |
#resolved_compilation_result ⇒ String
Output only. The resolved compilation result that was used to create this
invocation. Will be in the format projects/*/locations/*/repositories/*/
compilationResults/*.
Corresponds to the JSON property resolvedCompilationResult
4138 4139 4140 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 4138 def resolved_compilation_result @resolved_compilation_result end |
#state ⇒ String
Output only. This workflow invocation's current state.
Corresponds to the JSON property state
4143 4144 4145 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 4143 def state @state end |
#workflow_config ⇒ String
Immutable. The name of the workflow config to invoke. Must be in the format
projects/*/locations/*/repositories/*/workflowConfigs/*.
Corresponds to the JSON property workflowConfig
4149 4150 4151 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 4149 def workflow_config @workflow_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4156 4157 4158 4159 4160 4161 4162 4163 4164 4165 4166 4167 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 4156 def update!(**args) @compilation_result = args[:compilation_result] if args.key?(:compilation_result) @data_encryption_state = args[:data_encryption_state] if args.key?(:data_encryption_state) @internal_metadata = args[:internal_metadata] if args.key?(:internal_metadata) @invocation_config = args[:invocation_config] if args.key?(:invocation_config) @invocation_timing = args[:invocation_timing] if args.key?(:invocation_timing) @name = args[:name] if args.key?(:name) @private_resource_metadata = args[:private_resource_metadata] if args.key?(:private_resource_metadata) @resolved_compilation_result = args[:resolved_compilation_result] if args.key?(:resolved_compilation_result) @state = args[:state] if args.key?(:state) @workflow_config = args[:workflow_config] if args.key?(:workflow_config) end |