Class: Google::Apis::DataformV1::WorkflowInvocationAction
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1::WorkflowInvocationAction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb
Overview
Represents a single action in a workflow invocation.
Instance Attribute Summary collapse
-
#bigquery_action ⇒ Google::Apis::DataformV1::BigQueryAction
Represents a workflow action that will run against BigQuery.
-
#canonical_target ⇒ Google::Apis::DataformV1::Target
Represents an action identifier.
-
#data_preparation_action ⇒ Google::Apis::DataformV1::DataPreparationAction
Represents a workflow action that will run a Data Preparation.
-
#failure_reason ⇒ String
Output only.
-
#internal_metadata ⇒ String
Output only.
-
#invocation_timing ⇒ Google::Apis::DataformV1::Interval
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive).
-
#notebook_action ⇒ Google::Apis::DataformV1::NotebookAction
Represents a workflow action that will run against a Notebook runtime.
-
#state ⇒ String
Output only.
-
#target ⇒ Google::Apis::DataformV1::Target
Represents an action identifier.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkflowInvocationAction
constructor
A new instance of WorkflowInvocationAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkflowInvocationAction
Returns a new instance of WorkflowInvocationAction.
4243 4244 4245 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 4243 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bigquery_action ⇒ Google::Apis::DataformV1::BigQueryAction
Represents a workflow action that will run against BigQuery.
Corresponds to the JSON property bigqueryAction
4194 4195 4196 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 4194 def bigquery_action @bigquery_action end |
#canonical_target ⇒ Google::Apis::DataformV1::Target
Represents an action identifier. If the action writes output, the output will
be written to the referenced database object.
Corresponds to the JSON property canonicalTarget
4200 4201 4202 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 4200 def canonical_target @canonical_target end |
#data_preparation_action ⇒ Google::Apis::DataformV1::DataPreparationAction
Represents a workflow action that will run a Data Preparation.
Corresponds to the JSON property dataPreparationAction
4205 4206 4207 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 4205 def data_preparation_action @data_preparation_action end |
#failure_reason ⇒ String
Output only. If and only if action's state is FAILED a failure reason is set.
Corresponds to the JSON property failureReason
4210 4211 4212 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 4210 def failure_reason @failure_reason end |
#internal_metadata ⇒ String
Output only. All the metadata information that is used internally to serve the
resource. For example: timestamps, flags, status fields, etc. The format of
this field is a JSON string.
Corresponds to the JSON property internalMetadata
4217 4218 4219 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 4217 def @internal_metadata end |
#invocation_timing ⇒ Google::Apis::DataformV1::Interval
Represents a time interval, encoded as a Timestamp start (inclusive) and a
Timestamp end (exclusive). The start must be less than or equal to the end.
When the start equals the end, the interval is empty (matches no time). When
both start and end are unspecified, the interval matches any time.
Corresponds to the JSON property invocationTiming
4225 4226 4227 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 4225 def invocation_timing @invocation_timing end |
#notebook_action ⇒ Google::Apis::DataformV1::NotebookAction
Represents a workflow action that will run against a Notebook runtime.
Corresponds to the JSON property notebookAction
4230 4231 4232 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 4230 def notebook_action @notebook_action end |
#state ⇒ String
Output only. This action's current state.
Corresponds to the JSON property state
4235 4236 4237 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 4235 def state @state end |
#target ⇒ Google::Apis::DataformV1::Target
Represents an action identifier. If the action writes output, the output will
be written to the referenced database object.
Corresponds to the JSON property target
4241 4242 4243 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 4241 def target @target end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 4258 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 4248 def update!(**args) @bigquery_action = args[:bigquery_action] if args.key?(:bigquery_action) @canonical_target = args[:canonical_target] if args.key?(:canonical_target) @data_preparation_action = args[:data_preparation_action] if args.key?(:data_preparation_action) @failure_reason = args[:failure_reason] if args.key?(:failure_reason) @internal_metadata = args[:internal_metadata] if args.key?(:internal_metadata) @invocation_timing = args[:invocation_timing] if args.key?(:invocation_timing) @notebook_action = args[:notebook_action] if args.key?(:notebook_action) @state = args[:state] if args.key?(:state) @target = args[:target] if args.key?(:target) end |