Class: Google::Apis::DataformV1::WorkflowInvocationAction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb

Overview

Represents a single action in a workflow invocation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkflowInvocationAction

Returns a new instance of WorkflowInvocationAction.



4245
4246
4247
# File 'lib/google/apis/dataform_v1/classes.rb', line 4245

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bigquery_actionGoogle::Apis::DataformV1::BigQueryAction

Represents a workflow action that will run against BigQuery. Corresponds to the JSON property bigqueryAction



4196
4197
4198
# File 'lib/google/apis/dataform_v1/classes.rb', line 4196

def bigquery_action
  @bigquery_action
end

#canonical_targetGoogle::Apis::DataformV1::Target

Represents an action identifier. If the action writes output, the output will be written to the referenced database object. Corresponds to the JSON property canonicalTarget



4202
4203
4204
# File 'lib/google/apis/dataform_v1/classes.rb', line 4202

def canonical_target
  @canonical_target
end

#data_preparation_actionGoogle::Apis::DataformV1::DataPreparationAction

Represents a workflow action that will run a Data Preparation. Corresponds to the JSON property dataPreparationAction



4207
4208
4209
# File 'lib/google/apis/dataform_v1/classes.rb', line 4207

def data_preparation_action
  @data_preparation_action
end

#failure_reasonString

Output only. If and only if action's state is FAILED a failure reason is set. Corresponds to the JSON property failureReason

Returns:

  • (String)


4212
4213
4214
# File 'lib/google/apis/dataform_v1/classes.rb', line 4212

def failure_reason
  @failure_reason
end

#internal_metadataString

Output only. All the metadata information that is used internally to serve the resource. For example: timestamps, flags, status fields, etc. The format of this field is a JSON string. Corresponds to the JSON property internalMetadata

Returns:

  • (String)


4219
4220
4221
# File 'lib/google/apis/dataform_v1/classes.rb', line 4219

def 
  @internal_metadata
end

#invocation_timingGoogle::Apis::DataformV1::Interval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property invocationTiming



4227
4228
4229
# File 'lib/google/apis/dataform_v1/classes.rb', line 4227

def invocation_timing
  @invocation_timing
end

#notebook_actionGoogle::Apis::DataformV1::NotebookAction

Represents a workflow action that will run against a Notebook runtime. Corresponds to the JSON property notebookAction



4232
4233
4234
# File 'lib/google/apis/dataform_v1/classes.rb', line 4232

def notebook_action
  @notebook_action
end

#stateString

Output only. This action's current state. Corresponds to the JSON property state

Returns:

  • (String)


4237
4238
4239
# File 'lib/google/apis/dataform_v1/classes.rb', line 4237

def state
  @state
end

#targetGoogle::Apis::DataformV1::Target

Represents an action identifier. If the action writes output, the output will be written to the referenced database object. Corresponds to the JSON property target



4243
4244
4245
# File 'lib/google/apis/dataform_v1/classes.rb', line 4243

def target
  @target
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
# File 'lib/google/apis/dataform_v1/classes.rb', line 4250

def update!(**args)
  @bigquery_action = args[:bigquery_action] if args.key?(:bigquery_action)
  @canonical_target = args[:canonical_target] if args.key?(:canonical_target)
  @data_preparation_action = args[:data_preparation_action] if args.key?(:data_preparation_action)
  @failure_reason = args[:failure_reason] if args.key?(:failure_reason)
  @internal_metadata = args[:internal_metadata] if args.key?(:internal_metadata)
  @invocation_timing = args[:invocation_timing] if args.key?(:invocation_timing)
  @notebook_action = args[:notebook_action] if args.key?(:notebook_action)
  @state = args[:state] if args.key?(:state)
  @target = args[:target] if args.key?(:target)
end