Class: Google::Apis::DataformV1::Workspace
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1::Workspace
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb
Overview
Represents a Dataform Git workspace.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#data_encryption_state ⇒ Google::Apis::DataformV1::DataEncryptionState
Describes encryption state of a resource.
-
#disable_moves ⇒ Boolean
(also: #disable_moves?)
Optional.
-
#internal_metadata ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#private_resource_metadata ⇒ Google::Apis::DataformV1::PrivateResourceMetadata
Metadata used to identify if a resource is user scoped.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Workspace
constructor
A new instance of Workspace.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Workspace
Returns a new instance of Workspace.
4282 4283 4284 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 4282 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp of when the workspace was created.
Corresponds to the JSON property createTime
4251 4252 4253 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 4251 def create_time @create_time end |
#data_encryption_state ⇒ Google::Apis::DataformV1::DataEncryptionState
Describes encryption state of a resource.
Corresponds to the JSON property dataEncryptionState
4256 4257 4258 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 4256 def data_encryption_state @data_encryption_state end |
#disable_moves ⇒ Boolean Also known as: disable_moves?
Optional. If set to true, workspaces will not be moved if its linked
Repository is moved. Instead, it will be deleted.
Corresponds to the JSON property disableMoves
4262 4263 4264 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 4262 def disable_moves @disable_moves end |
#internal_metadata ⇒ String
Output only. All the metadata information that is used internally to serve the
resource. For example: timestamps, flags, status fields, etc. The format of
this field is a JSON string.
Corresponds to the JSON property internalMetadata
4270 4271 4272 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 4270 def @internal_metadata end |
#name ⇒ String
Identifier. The workspace's name.
Corresponds to the JSON property name
4275 4276 4277 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 4275 def name @name end |
#private_resource_metadata ⇒ Google::Apis::DataformV1::PrivateResourceMetadata
Metadata used to identify if a resource is user scoped.
Corresponds to the JSON property privateResourceMetadata
4280 4281 4282 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 4280 def @private_resource_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4287 4288 4289 4290 4291 4292 4293 4294 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 4287 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @data_encryption_state = args[:data_encryption_state] if args.key?(:data_encryption_state) @disable_moves = args[:disable_moves] if args.key?(:disable_moves) @internal_metadata = args[:internal_metadata] if args.key?(:internal_metadata) @name = args[:name] if args.key?(:name) @private_resource_metadata = args[:private_resource_metadata] if args.key?(:private_resource_metadata) end |