Class: Google::Apis::DataformV1::WorkspaceCompilationOverrides
- Inherits:
-
Object
- Object
- Google::Apis::DataformV1::WorkspaceCompilationOverrides
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb
Overview
Configures workspace compilation overrides for a repository.
Instance Attribute Summary collapse
-
#default_database ⇒ String
Optional.
-
#schema_suffix ⇒ String
Optional.
-
#table_prefix ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkspaceCompilationOverrides
constructor
A new instance of WorkspaceCompilationOverrides.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkspaceCompilationOverrides
Returns a new instance of WorkspaceCompilationOverrides.
4328 4329 4330 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 4328 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_database ⇒ String
Optional. The default database (Google Cloud project ID).
Corresponds to the JSON property defaultDatabase
4315 4316 4317 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 4315 def default_database @default_database end |
#schema_suffix ⇒ String
Optional. The suffix that should be appended to all schema (BigQuery dataset
ID) names.
Corresponds to the JSON property schemaSuffix
4321 4322 4323 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 4321 def schema_suffix @schema_suffix end |
#table_prefix ⇒ String
Optional. The prefix that should be prepended to all table names.
Corresponds to the JSON property tablePrefix
4326 4327 4328 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 4326 def table_prefix @table_prefix end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4333 4334 4335 4336 4337 |
# File 'lib/google/apis/dataform_v1/classes.rb', line 4333 def update!(**args) @default_database = args[:default_database] if args.key?(:default_database) @schema_suffix = args[:schema_suffix] if args.key?(:schema_suffix) @table_prefix = args[:table_prefix] if args.key?(:table_prefix) end |