Class: Google::Apis::DataformV1::WorkspaceCompilationOverrides

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dataform_v1/classes.rb,
lib/google/apis/dataform_v1/representations.rb,
lib/google/apis/dataform_v1/representations.rb

Overview

Configures workspace compilation overrides for a repository.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkspaceCompilationOverrides

Returns a new instance of WorkspaceCompilationOverrides.



4317
4318
4319
# File 'lib/google/apis/dataform_v1/classes.rb', line 4317

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_databaseString

Optional. The default database (Google Cloud project ID). Corresponds to the JSON property defaultDatabase

Returns:

  • (String)


4304
4305
4306
# File 'lib/google/apis/dataform_v1/classes.rb', line 4304

def default_database
  @default_database
end

#schema_suffixString

Optional. The suffix that should be appended to all schema (BigQuery dataset ID) names. Corresponds to the JSON property schemaSuffix

Returns:

  • (String)


4310
4311
4312
# File 'lib/google/apis/dataform_v1/classes.rb', line 4310

def schema_suffix
  @schema_suffix
end

#table_prefixString

Optional. The prefix that should be prepended to all table names. Corresponds to the JSON property tablePrefix

Returns:

  • (String)


4315
4316
4317
# File 'lib/google/apis/dataform_v1/classes.rb', line 4315

def table_prefix
  @table_prefix
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4322
4323
4324
4325
4326
# File 'lib/google/apis/dataform_v1/classes.rb', line 4322

def update!(**args)
  @default_database = args[:default_database] if args.key?(:default_database)
  @schema_suffix = args[:schema_suffix] if args.key?(:schema_suffix)
  @table_prefix = args[:table_prefix] if args.key?(:table_prefix)
end